function drawJT( )
	clc;
	
	Q10 =  0.05311622;
	Q20 =  0.10889444;
	Q33 =  0.09553010;
	Q34 =  0.11920850;
	beta = 1.5;
%	lambda = 7.407;	% t=0.9
	lambda = 3.509;	% t=1.5

	dE_brtg = beta * lambda * Q10;
	dE_JT_Mn3 = lambda * sqrt(Q20^2 + Q33^2);
	dE_JT_Mn4 = lambda * abs(Q34);

	
	figure(1); clf;	
	minmax_x = [0,4];
	minmax_y = 2.1*[-1,1];
	
	% DRAW 0 LINE
	line(minmax_x, [0,0], 'LineStyle','-', 'Color',[1,.8,0])
	
	% DRAW ALL SPLITS:
	dE = 1.5;
	xSp = 0.2;
	xBr = 0.5;
	posL = [minmax_x(1),0];
	posR = [minmax_x(2),0];
	% Mn3 branching
	[posTopBr3, ~] = DrawSplit(posL, posL(2), 0,xBr, 1,1, 0);
	[~, posBotJT3] = DrawSplit(posTopBr3, dE_brtg, xSp,xBr, 2,1);
	[posTop3, posBot3] = DrawSplit(posBotJT3, dE_JT_Mn3, xSp,xBr, 3,1);
	% Mn4 branching
	[posTopBr4, ~] = DrawSplit(posR, posR(2), 0,xBr, 1,-1, 0);
	[posTopJT4, ~] = DrawSplit(posTopBr4, dE_brtg, xSp,xBr, 1,-1);
	[~, posBot4] = DrawSplit(posTopJT4, dE_JT_Mn4, xSp,xBr, 3,-1);
	
	% DRAW Mn3/Mn4 STUFF:
	text(minmax_x(1)+.05, 0, 'Mn^{3+}', 'Color',[1,0,0], 'FontWeight','bold', 'FontSize',15,...
		'HorizontalAlignment','left', 'VerticalAlignment','bottom');
	text(minmax_x(2)-.05, 0, 'Mn^{4+}', 'Color',[0,0,1], 'FontWeight','bold', 'FontSize',15,...
		'HorizontalAlignment','right', 'VerticalAlignment','bottom');
	
	% TEXT PARAMS:
	gap = min( abs(posBot3(2) - posBot4(2)), abs(posBot3(2) - posTop3(2)) );
	text(minmax_x(1)+.1, minmax_y(2)-.1, ...
		sprintf(['\\beta = %.1f\n','\\lambda = %.3f (A/eV)\n','\\Delta{Br} = %.3f (eV)\n',...
		'\\Delta{JT} = %.3f (eV)\n','\\Delta{JT Mn3} = %.3f (eV)\n','\\Delta{JT Mn4} = %.3f (eV)'], ...
		beta,lambda, dE_brtg, gap, 2*dE_JT_Mn3, 2*dE_JT_Mn4),...
		'HorizontalAlignment','left', 'VerticalAlignment','top');
	
	% DRAW JT GAP
	clrJT = [0,.6,0];
	xPos = (minmax_x(2)-minmax_x(1)) / 2;
	line( [1,1]*xPos, posBot3(2)+[0,gap], 'LineStyle','-', 'LineWidth',2, 'Color',clrJT);
	text(xPos, posBot3(2)+gap/2, '\Delta{JT}', 'Color',clrJT,...
		'HorizontalAlignment','center', 'VerticalAlignment','middle', 'BackgroundColor','w');
	
	xlim(minmax_x);
	ylim(minmax_y);
	box('on');
	ylabel('Energy (eV)');
	title('Jahn-Teller Gap')
	set(gca, 'XTick',[]);
	
end

%====================================================================
% pos = [x,y]		: starting position
% dE				: dE split amount (y value)
% xSp				: x amount for split
% xBr				: x amount for branch length
% style = {1,2,3}	: 1-top,2-bottom,3-both
% dir = {+1,-1}		: direction +1:left->right, -1:right->left
function [posTop, posBot] = DrawSplit(pos, dE,xSp,xBr, style,dir,isText)
	if nargin < 7
		isText = 1;
	end
	clrLink = 0.6*[1,1,1];
	clrBar  = [0,0,0];
	lw = 3;

	x0 = pos(1);
	x1 = x0 + dir*xSp;
	x2 = x1 + dir*xBr;
	y0 = pos(2);
	y1 = y0 + dE;
	y2 = y0 - dE;
	if style == 1 || style == 3
		% top branch
		if isText == 1
			text(x1+(x2-x1)/2, y1, sprintf('%.3f eV',y1), ...
				'HorizontalAlignment','center', 'VerticalAlignment','bottom');
		end
		line([x0,x1], [y0,y1], 'Color',clrLink, 'LineStyle','-', 'LineWidth',1);
		line([x1,x2], [y1,y1], 'Color',clrBar, 'LineStyle','-', 'LineWidth',lw);
	end
	if style == 2 || style == 3
		% bottom branch
		if isText == 1
			text(x1+(x2-x1)/2, y2, sprintf('%.3f eV',y2), ...
				'HorizontalAlignment','center', 'VerticalAlignment','bottom');
		end
		line([x0,x1], [y0,y2], 'Color',clrLink, 'LineStyle','-', 'LineWidth',1);
		line([x1,x2], [y2,y2], 'Color',clrBar, 'LineStyle','-', 'LineWidth',lw);
	end
	posTop = [x2,y1];
	posBot = [x2,y2];
end

