function figure1()
	clc; addpath('../../_common_');
	isSaveEPS = 1;
	figId = 10;
	%--------------------------------------------
	figId = FigId(figId,'figure 1a');
	PlotFigA();
	if isSaveEPS; fig2eps(gcf,'fig1a'); end;

	figId = FigId(figId,'figure 1b');
	PlotFigB();
	if isSaveEPS; fig2eps(gcf,'fig1b'); end;

	figId = FigId(figId,'figure 1c');
	PlotFigC();
	if isSaveEPS; fig2eps(gcf,'fig1c'); end;
end

function PlotFigA()
	minmax_x = [0,5];
	minmax_y = [0,2.8];
	FontSize = 20 * (22/19.3);
	lw = 2;
	ms = 10;
	%--------------------------------------------
	% loading data
	mth3 = [-24,     -19,   -14,    -8, -0.5,  5.5,   12];
	mAlpha = mth3 + 41.1273;
	mBeta = 68 - mAlpha;
	% the universal scaling factor to bring back intensity into counts
	theR = 2.38e9;
	% absorption correction 1+sin(pi*mAlpha/180.)/sin(pi*mBeta/180.)
	abFactor = 1+(sin(pi*mAlpha/180.))./sin(pi*mBeta./180.);

	S176 = load('data/Scan176.dat');
	S185 = load('data/Scan185.dat');
	S190 = load('data/Scan190.dat');
	S195 = load('data/Scan195.dat');
	S200 = load('data/Scan200.dat');
	S205 = load('data/Scan205.dat');
	S210 = load('data/Scan210.dat');
	SList3 = [S176, S185, S190, S195, S200, S205, S210];
	%--------------------------------------------
	% plotting
	hold on;
%	clr = [0,0,0;  0,0,1;  1,0,0];	% black,blue,red
%	clrF = clr;
	clr  = [0,0,0;  0,0,0;  0,0,0];	% all black
	clrF = [1,1,1;  0.8,0.8,0.8;  0,0,0];

	k = 2;	i = (k-1)*4;
	tx = -SList3(:,i+1)*1000;
	ty = SList3(:,i+2)*theR*abFactor(k) ./ 1000;	
	h2 = plot(tx, ty, '-o', 'Color',clr(1,:), 'MarkerFaceColor',clrF(1,:), ...
		'MarkerSize',ms, 'LineWidth',lw);
	
	k = 3; i = (k-1)*4;
	tx = -SList3(:,i+1)*1000;
	ty = SList3(:,i+2)*theR*abFactor(k) ./ 1000;
	h3 = plot(tx, ty, '-s', 'Color',clr(2,:), 'MarkerFaceColor',clrF(2,:), ...
		'MarkerSize',ms, 'LineWidth',lw);

	k = 4; i = (k-1)*4;
	tx = -SList3(:,i+1)*1000;
	ty = SList3(:,i+2)*theR*abFactor(k) ./ 1000;
	h4 = plot(tx, ty, '-d', 'Color',clr(3,:), 'MarkerFaceColor',clrF(3,:), ...
		'MarkerSize',ms, 'LineWidth',lw);
	hold off;
	%--------------------------------------------
	% axis adjustment
	
	box('on');
	xlim(minmax_x);
	ylim(minmax_y);
	set(gca,'XTick',0:5, 'FontSize',FontSize)
	set(gca,'YTick',0:0.5:2.5, 'YTickLabel',{'0','','1','','2',''}, 'FontSize',FontSize)
	set(gca, 'LineWidth',2, 'FontSize',FontSize);
	
	xlabel('Energy loss (eV)','FontSize',FontSize)
	ylabel('Intensity (1000 counts)','FontSize',FontSize)

	cLeg = {'Q = (-0.33, -0.33, 7.04)';...
			'Q = (-0.19, -0.19, 7.15)';...
			'Q = (-0.03, -0.03, 7.20)'};
	hleg = legend([h2,h3,h4],cLeg);
	set(hleg,'Box','off');

	set(gca,'PlotBoxAspectRatio',[1 .5 1]);
end

function PlotFigB()
	minmax_x = 0.75*[-1,1];
	minmax_y = [5.8, 9.7];
	FontSize = 35 * (22/17.5);
	%--------------------------------------------
	% generate the three lines in R space.
	a = 3.86; c = 12.17;
	k =2*pi / 1.891;

	QH2 = -0.8:0.02:0.8;
	Qmax = 2*k*sin(78/2/180*pi);
	Qp = QH2*sqrt(2)*2*pi/a;
	Qv2 = sqrt(Qmax^2-Qp.^2)/(2*pi)*c;
	
	Qmax = 2*k*sin(68/2/180*pi);
	Qp = QH2*sqrt(2)*2*pi/a;
	Qv3 = sqrt(Qmax^2-Qp.^2)/(2*pi)*c;

	% for th fixed
	mtth1 = 50:0.2:100;
	mAlpha = 41.1273;
	mBeta = mtth1-mAlpha;

	Li = k*sin(mAlpha/180*pi);  Hi = k*cos(mAlpha/180*pi);
	Le = k*sin(mBeta./180*pi);  He = k*cos(mBeta./180*pi);
	fL = Le+Li;                 fH = Hi-He;
	QL1 = fL*c/2/pi;            QH1 = -fH*a/2/pi/sqrt(2);

	hold on;
	lw = 2;
%	clr  = [0,0,0;  0,0,0;  0,0,0];	% all black
	clr  = [0,0,0;  0,0,1;  1,0,0];	% color
	h1 = plot(QH1, QL1, '-',  'Color',clr(1,:), 'LineWidth',lw);
	h2 = plot(QH2, Qv2, '--', 'Color',clr(2,:), 'LineWidth',lw);
	h3 = plot(QH2, Qv3, '-.',  'Color',clr(3,:), 'LineWidth',lw);
	

	%--------------------------------------------
	% plot HL data
	dHLI_k = load('data/HLI_k.txt');
	dHLI_b = load('data/HLI_b.txt');
	dHLI_r = load('data/HLI_r.txt');
	
	I_max = max([dHLI_k(:,3); dHLI_b(:,3); dHLI_r(:,3)]);
	ms_max = 38;
	
	clr_k = [0,0,0];
	clr_b = [0,0,1];
	clr_r = [1,0,0];
	
	mshift = [0.08 -0.06 -0.03 -0.005 -0.01 0.01 0.05 0.07 0.09 0.14];
	for i = 1:size(dHLI_k,1)
		plot(dHLI_k(i,1),dHLI_k(i,2)+mshift(i), 'o', 'Color',clr_k, ...
			'MarkerFaceColor',clr_k, 'MarkerSize',ms_max*dHLI_k(i,3)/I_max);
	end
	
	for i = 1:size(dHLI_b,1)
		plot(dHLI_b(i,1),dHLI_b(i,2), 'o', 'Color',clr_b, ...
			'MarkerFaceColor',clr_b, 'MarkerSize',ms_max*dHLI_b(i,3)/I_max);
	end
	
	for i = 1:size(dHLI_r,1)
		plot(dHLI_r(i,1),dHLI_r(i,2), 'o', 'Color',clr_r, ...
			'MarkerFaceColor',clr_r, 'MarkerSize',ms_max*dHLI_r(i,3)/I_max);
	end
	
	%--------------------------------------------
	% axis adjustment
	box('on');
	xlim(minmax_x);
	ylim(minmax_y);
	set(gca,'XTick',-0.75:0.25:0.75, ...
		'XTickLabel',{'','-0.5','','0','','0.5',''}, 'FontSize',FontSize);
	set(gca,'YTick',5:10, 'FontSize',FontSize);
	set(gca, 'LineWidth',2, 'FontSize',FontSize);
	
	xlabel('H (r.l.u.)', 'FontSize',FontSize);
	ylabel('L (r.l.u.)', 'FontSize',FontSize);

	cLeg = {'  \theta = 40\circ';...
			'2\theta = 78\circ';...
			'2\theta = 68\circ'};
	[hleg,hobj,~,~] = legend([h1,h2,h3],cLeg);
	set(hleg,'Box','off');
	
%{-
	xsh = -0.025;
	% adding circles to legend
	hp = get(hobj(4),'Parent'); x = get(hobj(4),'XData'); y = get(hobj(4),'YData');
	plot(hp, x(1)+xsh,y(1),'o', 'MarkerSize',ms_max/2, 'MarkerFaceColor',clr_k, 'Color',clr_k);
	
	hp = get(hobj(6),'Parent'); x = get(hobj(6),'XData'); y = get(hobj(6),'YData');
	plot(hp, x(1)+xsh,y(1),'o', 'MarkerSize',ms_max/2, 'MarkerFaceColor',clr_b, 'Color',clr_b);
	
	hp = get(hobj(8),'Parent'); x = get(hobj(8),'XData'); y = get(hobj(8),'YData');
	plot(hp, x(1)+xsh,y(1),'o', 'MarkerSize',ms_max/2, 'MarkerFaceColor',clr_r, 'Color',clr_r);
%}	

	set(gca,'PlotBoxAspectRatio',[.75 1 1]);
end

function PlotFigC()
	minmax_x = [0, 7];
	minmax_y = [0, 6.5];
	FontSize = 35 * (22/17.5);
	lw = 2;
	ms = 12;
	%--------------------------------------------
	% plot background strip
	clr_bkg = 0.8*[1,1,1];
	rectangle('Position',[1,minmax_y(1), 2,(minmax_y(2)-minmax_y(1))], ...
		'Curvature',[0,0], 'FaceColor',clr_bkg, 'EdgeColor','none', 'EraseMode','background');
	%--------------------------------------------
	% loading data
	mth3 = [-24,     -19,   -14,    -8, -0.5,  5.5,   12];
	mAlpha = mth3 + 41.1273;
	mBeta = 68 - mAlpha;
	% the universal scaling factor to bring back intensity into counts
	theR = 2.38e9;
	% absorption correction 1+sin(pi*mAlpha/180.)/sin(pi*mBeta/180.)
	abFactor = 1+(sin(pi*mAlpha/180.))./sin(pi*mBeta./180.);

	S176 = load('data/Scan176.dat');
	S185 = load('data/Scan185.dat');
	S190 = load('data/Scan190.dat');
	S195 = load('data/Scan195.dat');
	S200 = load('data/Scan200.dat');
	S205 = load('data/Scan205.dat');
	S210 = load('data/Scan210.dat');
	SList3 = [S176, S185, S190, S195, S200, S205, S210];
	
	mH3  = [-0.47, -0.33, -0.19, -0.03, 0.19, 0.35, 0.53];
	
	% put tth=78 and th fixed together
	m = 3;		% select which curve to plot - m=3 is the absorption corrected intensity
	a = 800;
	hold on;
	xTxt = 6.7;
	for j=1:7		
		k = 8-j; % reverse the sequence of the plot
		i = (k-1)*4;
		ssx = -SList3(:,i+1)*1000;
		tsy = SList3(:,i+m)*theR*abFactor(k);

		ssy = (tsy+a*(j-1)) / 1000;
		range = 8:33;
		plot(ssx(range),ssy(range),'-o', 'Color',[0,0,0], 'MarkerFaceColor',[0,0,0], ...
			'LineWidth',lw, 'MarkerSize',ms);

		text(xTxt, (400+a*(j-1))/1000, num2str(mH3(k),'%.2f'), 'FontSize',FontSize, ...
			'HorizontalAlignment','right');
	end
	text(xTxt, 5.7, 'H = ', 'FontSize',FontSize, 'HorizontalAlignment','right');
	hold off;
	%--------------------------------------------
	% axis adjustment	
	box('on');
	xlim(minmax_x);
	ylim(minmax_y);
	set(gca,'XTick',0:5, 'XTickLabel',0:5, 'FontSize',FontSize);
	set(gca,'YTick',0:7, 'FontSize',FontSize);
	set(gca, 'LineWidth',2, 'FontSize',FontSize);
	
	xlabel('Energy loss (eV)', 'FontSize',FontSize);
	ylabel('Intensity (1000 counts)', 'FontSize',FontSize);

	set(gca,'PlotBoxAspectRatio',[.75 1 1]);
end