function plot_ls_vs_t0()
	clc; addpath('../../_common_');
	
	isSaveEPS = 1;
	figId = 15;

	% read file [special_data_descr.txt] for description
	data = load('special_data.txt');

	PlotFig(figId, data);
	if isSaveEPS; fig2eps(gcf,'ls-t0'); end;

end

function PlotFig(figId, data)
	figure(figId); clf;
	hold all;

	minmax_x = [0,1.5];
	minmax_y = [0, 8];
	Pn = 2;
	cPn = {'Linear fit', 'Quadratic fit'};
	
	
	x = minmax_x(1):0.01:minmax_x(2);
	% poly fit BLUE
	p3 = polyfit(data(1:4,1), data(1:4,3), Pn);
	plot(x,polyval(p3,x),'--b', 'LineWidth',2);
		
	% poly fit RED
	p4 = polyfit(data(:,1), data(:,4), Pn);
	plot(x,polyval(p4,x),'--r', 'LineWidth',2);
	
	
	ms = 10;
	hl1 = plot(data(:,1), data(:,3),'o', 'Color','b', ...
		'LineWidth',2, 'MarkerSize',ms, 'MarkerFaceColor','b');
	hl2 = plot(data(:,1), data(:,4),'o', 'Color','r', ...
		'LineWidth',2, 'MarkerSize',ms, 'MarkerFaceColor','none');
	
	
	% axis adjustments:
	FontSize = 16;
	box('on');
	set(gca, 'LineWidth',2, 'FontSize',FontSize);
	xlim(minmax_x);
	ylim(minmax_y);
	xlabel('t_0 (eV)', 'FontSize',FontSize);
	ylabel('l_{s}', 'FontSize',FontSize);
	title(sprintf('%s, y-intercept at: y_0^{Mn3+} = %.2f, y_0^{Mn4+} = %.2f', cPn{Pn}, p3(end), p4(end) ));
	
	cLeg = {'Mn^{3+}';'Mn^{4+}'};
	legend([hl1,hl2], cLeg, 'Location','NorthWest', 'LineWidth',2);
	
%	set(gca, 'PlotBoxAspectRatio',[1 1 1]);
end