function plot_special()
	clc; addpath('../../_common_');
	
	isSaveEPS = 1;
	figId = 10;

	% read file [special_data_descr.txt] for description
	data = load('special_data.txt');
%{-
	PlotPRB(figId, data);
	if isSaveEPS; fig2eps(gcf,'gamam-ls'); end;
%return
%}
	PlotPRB2(figId+1, data);
	if isSaveEPS; fig2eps(gcf,'wDelta-ls'); end;
end

%=============================================================

function PlotPRB(figId, data)
	figure(figId); clf;
	
	dev(:,[1,2]) = data(:,[1,5]);

	t0 = data(:,1);
	nt = length(t0);
	for i = 1:nt
		CH = 1;
		dat_fit = load(sprintf('data_files/zigzag_t%.2f_CH%d_fit-param.txt', t0(i),CH));
		lam1 = dat_fit(1,2);
		CH = 2;
		dat_fit = load(sprintf('data_files/zigzag_t%.2f_CH%d_fit-param.txt', t0(i),CH));
		lam2 = dat_fit(1,2);
		
		dev(i,3:4) = [lam1,lam2];
	end
	
% data truncation:
%dev = dev(1:4,:);

	%minmax_x = [0,1.5];
	minmax_x = [0,1.5];
	minmax_y = [0.25, 0.4];
	ms = 10;
	hold on;
	% draw vertical line
%	plot(0.34*[1,1], minmax_y, '--k', 'LineWidth',1.5);
	
	hl1 = plot(dev(:,3),dev(:,2),'o', 'Color','b', ...
		'LineWidth',2, 'MarkerSize',ms, 'MarkerFaceColor','b');
	hl2 = plot(dev(:,4),dev(:,2),'o', 'Color','r', ...
		'LineWidth',2, 'MarkerSize',ms, 'MarkerFaceColor','none');
	hold off;
	
	% axis adjustments:
	FontSize = 16;
	axis('tight','square');
	box('on');
	
	for i=1:4
		str = sprintf(' \\leftarrow %.1f eV',dev(i,1));
		text(dev(i,4)+0.03, dev(i,2)+0.001, str,...
			'HorizontalAlignment','left', 'VerticalAlignment','middle', ...
			'FontSize',FontSize);
	end
	
	set(gca, 'LineWidth',2, 'FontSize',FontSize);
	
	xlim(minmax_x);
	ylim(minmax_y);
	
	xlabel('l_{s}', 'FontSize',FontSize);
	ylabel('\gamma_{H} (r.l.u.)', 'FontSize',FontSize);
	
	cLeg = {'Mn^{3+}';'Mn^{4+}'};
	hl = legend([hl1,hl2], cLeg,     'Location','West', 'LineWidth',2);	% 'NorthWest'
%	set(hl,'Box','off');
	
%	set(gca, 'YAxisLocation','right');
%	set(gca, 'YTick',0:0.2:1)
	
	set(gca, 'PlotBoxAspectRatio',[1 1 1]);
end

function PlotPRB2(figId, data)
	figure(figId); clf;
	nt = size(data,1);
	
	minmax_x = [0, 15];
	minmax_y = [0.25, 0.4];
	ms = 10;
	
	mn3 = [data(:,1), data(:,6), data(:,5)];
	mn4 = [data(:,1), data(:,7), data(:,5)];
	
	% remove INF data entries
	mn3 = mn3(mn3(:,2)~=-1, :);
	mn4 = mn4(mn4(:,2)~=-1, :);

	
	p = polyfit(mn4(:,2), mn4(:,3), 1);
	x = 0.01:0.01:3;
	y = p(2) + p(1)*x;
	plot(x,y,'--r', 'LineWidth',2);
	
	hold on;	
	h1 = semilogy(mn3(:,2), mn3(:,3), 's', 'Color','b', ...
		'LineWidth',2, 'MarkerSize',ms, 'MarkerFaceColor','b');
	h2 = plot(mn4(:,2), mn4(:,3), 's', 'Color','r', ...
		'LineWidth',2, 'MarkerSize',ms, 'MarkerFaceColor','none');
	

	hold off;
	
	% axis adjustments:
	FontSize = 16;
	axis('tight','square');
	box('on');
	cLeg = {'Mn^{3+}';'Mn^{4+}'};
	hl = legend([h1,h2],cLeg, 'Location','East', 'LineWidth',2);
	xlim(minmax_x);
	ylim(minmax_y);
	xlabel('W/\Delta', 'FontSize',FontSize);
	ylabel('\gamma_{H} (r.l.u.)', 'FontSize',FontSize);
	set(gca, 'LineWidth',2, 'FontSize',FontSize);
	
%	set(gca, 'YAxisLocation','right');
	set(gca, 'PlotBoxAspectRatio',[1 1 1]);
end







