function plot_zigzag()
	clc; addpath('../../_common_');
	
	isSaveEPS = 1;
	figId = 1;
%{-
	t0 = [0.1, 0.6, 0.9, 1.1, 1.3, 1.32, 1.33, 1.35, 1.4, 1.5];
	PlotAllZigzag(figId, t0);
	if isSaveEPS
		fig2eps(gcf-1,'zigzag-mn3');
		fig2eps(gcf,'zigzag-mn4');
	end
return
%}
	
%{
	PlotPRLZigzag(figId+2);
	if isSaveEPS; fig2eps(gcf,'zigzag'); end;
return;
%}
	
	PlotPRLDev(figId+3);
	if isSaveEPS; fig2eps(gcf,'dev'); end;
end

function figId = PlotAllZigzag(figId, t0)
	nt = length(t0);
	clr = jet(nt);
	figure(figId); clf;
%	subplot(2,1,1); 
	hold all;
	CH = 1;
	for i = 1:nt
		xyZig = load(sprintf('data_files/zigzag_t%.2f_CH%d.txt', t0(i),CH));
		plot(xyZig(:,1), abs(xyZig(:,2)), 'o-', 'Color',clr(i,:), ...
			'LineWidth',2, 'MarkerSize',4, 'MarkerFaceColor',clr(i,:));
	end
	hold off;
	FixAxis(t0,CH);
	
	figure(figId+1); clf;
	%subplot(2,1,2); 
	hold all;
	CH = 2;
	for i = 1:length(t0)
		xyZig = load(sprintf('data_files/zigzag_t%.2f_CH%d.txt', t0(i),CH));
		plot(xyZig(:,1), abs(xyZig(:,2)), 'o-', 'Color',clr(i,:), ...
			'LineWidth',2, 'MarkerSize',4, 'MarkerFaceColor',clr(i,:));
	end
	hold off;
	FixAxis(t0,CH);
end
function FixAxis(t0,CH)
	% axis adjustments:
	FontSize = 15;
	box('on');
	xlim([0,8]);
	ylim([1e-10,1]);	
	set(gca, 'YScale','log');
	set(gca, 'LineWidth',2, 'FontSize',FontSize);
	stCH = {'Mn3+','Mn4+'};
	xlabel( sprintf('Distance form core hole along zig-zag path') );
	ylabel('Normalized hole density');
	
	% legend:
	for i = 1:length(t0)
		dat_fit = load(sprintf('data_files/zigzag_t%.2f_CH%d_fit-param.txt', t0(i),CH));
		%{
		if CH==1 && t0(i)>= 1.32
			cLeg{i,1} = sprintf('%.2f (n/a)', t0(i));
		else
			%cLeg{i,1} = sprintf('t_0= %.2f, l_{s} \\approx %.2f', t0(i),dat_fit(2));
			cLeg{i,1} = sprintf('%.2f (%.2f)', t0(i),dat_fit(2));
		end
		%}
		cLeg{i,1} = sprintf('%.2f', t0(i));
	end
	legend(cLeg);
	legend('Location','SouthWest');
	
	set(gca,'PlotBoxAspectRatio',[1 .5 1]);
end


%=============================================================
function PlotPRLZigzag(figId)
	figure(figId); clf;
	
    lw = 2;
    ms = 8;
	hold on;
    % plot blank for legend
    hl(1) = plot(0,0,'.w');
    
	t0 = 0.9;
	CH = 1;
	xyZig = load(sprintf('data_files/zigzag_t%.2f_CH%d.txt', t0,CH));
	hl(2) = plot(xyZig(:,1), -1*xyZig(:,2), 'o-', 'Color','b', ...
		'LineWidth',lw, 'MarkerSize',ms, 'MarkerFaceColor','b');
	CH = 2;
	xyZig = load(sprintf('data_files/zigzag_t%.2f_CH%d.txt', t0,CH));
	hl(3) = plot(xyZig(:,1), -1*xyZig(:,2), 'o--', 'Color','b', ...
		'LineWidth',lw, 'MarkerSize',ms, 'MarkerFaceColor','b');
	
	
	t0 = 1.5;
	CH = 1;
	xyZig = load(sprintf('data_files/zigzag_t%.2f_CH%d.txt', t0,CH));
	hl(4) = plot(xyZig(:,1), -1*xyZig(:,2), 'o-', 'Color','r', ...
		'LineWidth',lw, 'MarkerSize',ms, 'MarkerFaceColor','w');
	CH = 2;
	xyZig = load(sprintf('data_files/zigzag_t%.2f_CH%d.txt', t0,CH));
	hl(5) = plot(xyZig(:,1), -1*xyZig(:,2), 'o--', 'Color','r', ...
		'LineWidth',lw, 'MarkerSize',ms, 'MarkerFaceColor','w');
	
	hold off;
	
	% axis adjustments:
	FontSize = 20;
	axis('tight','square');
	set(gca, 'YScale','log')
	box('on');
	
	set(gca, 'LineWidth',2, 'FontSize',FontSize);
	
	ylim([1e-8,1]);
	xlim([0,8]);
	
	%xlabel('i_{chain}', 'FontSize',FontSize);
	xlabel('Distance from core hole site along chain', 'FontSize',FontSize);
%	ylabel('n_{hole}(i_{chain}) / n_{electron}(i_{core hole})', 'FontSize',FontSize);
	ylabel('Normalized hole density', 'FontSize',FontSize);
	
	cLeg = {'t_0 =   {core hole site}'; ...
			'0.9 eV    {Mn}^{3+}'; ...
			'0.9 eV    {Mn}^{4+}'; ...
			'1.5 eV    {Mn}^{3+}'; ...
			'1.5 eV    {Mn}^{4+}'};
	legend(hl,cLeg);
	hl = legend('Location','SouthWest');
	set(hl,'Box','off');
	
	set(gca, 'XTick',0:8);
	set(gca, 'YTick',10.^(-8:1:0));
%	set(gca, 'YAxisLocation','right');
	set(gca, 'YMinorTick','off');

	set(gca,'PlotBoxAspectRatio',[1 .6 1]);
end

function PlotPRLDev(figId)
	figure(figId); clf;
	
	dev = load('N16_deviations.txt');

	t0 = dev(:,1);
	nt = length(t0);
	for i = 1:nt
		CH = 1;
		dat_fit = load(sprintf('data_files/zigzag_t%.2f_CH%d_fit-param.txt', t0(i),CH));
		lam1 = dat_fit(1,2);
		CH = 2;
		dat_fit = load(sprintf('data_files/zigzag_t%.2f_CH%d_fit-param.txt', t0(i),CH));
		lam2 = dat_fit(1,2);
		
		dev(i,3:4) = [lam1,lam2];
	end
	
% data truncation:
dev = dev(1:4,:);
	
	minmax_y = [0,1.5];
	ms = 7;
	hold on;
	% draw vertical line
%	plot(0.34*[1,1], minmax_y, '--k', 'LineWidth',1.5);
	
	hl1 = plot(dev(:,2),dev(:,3),'o', 'Color','k', ...
		'LineWidth',2, 'MarkerSize',ms, 'MarkerFaceColor','k');
	hl2 = plot(dev(:,2),dev(:,4),'o', 'Color','k', ...
		'LineWidth',2, 'MarkerSize',ms, 'MarkerFaceColor','none');
	hold off;
	
	% axis adjustments:
	FontSize = 14;
	axis('tight','square');
	box('on');
	
	for i=1:4
		str = sprintf(' \\leftarrow %.1f eV',dev(i,1));
		text(dev(i,2)-0.002, dev(i,4)+0.03, str,...
			'HorizontalAlignment','left', 'VerticalAlignment','middle', ...
			'FontSize',FontSize, 'Rotation',90);
	end
	
	set(gca, 'LineWidth',2, 'FontSize',FontSize);
	
	%xlim([0.25, 0.37]);
	xlim([0.23, 0.36]);
	%ylim(minmax_y);
	ylim([0, 1]);
	
	xlabel('\gamma_{H} (r.l.u.)', 'FontSize',FontSize);
	ylabel('l_{s}', 'FontSize',FontSize);
	
	cLeg = {'Mn^{4+}';'Mn^{3+}'};
	hl = legend([hl2,hl1], cLeg,     'Location','SouthEast', 'LineWidth',2);	% 'NorthWest'
%	set(hl,'Box','off');
	
	set(gca, 'YAxisLocation','right');
	set(gca, 'YTick',0:0.2:1)
	
	set(gca,'PlotBoxAspectRatio',[.5 1 1]);
end









