function plot_fig2()
	clc;
	data = load('data_red.txt');
	H = load('data_red_H.txt');
	x = data(:,1);
	y = data(:,2:size(data,2));	
	kline = PlotData(1,x,y,H);
	ExportKLine(kline, 'data_exp_red.txt');
	PlotSurf(11,x,y,H);

	data = load('data_blu.txt');
	H = load('data_blu_H.txt');
	x = data(:,1);
	y = data(:,2:size(data,2));	
	kline = PlotData(2,x,y,H);
	ExportKLine(kline, 'data_exp_blue.txt');
	PlotSurf(12,x,y,H);
	
	data = load('data_blk.txt');
	H = load('data_blk_H.txt');
	x = data(:,1);
	y = data(:,2:size(data,2));
	kline = PlotData(3,x,y,H);
	ExportKLine(kline, 'data_exp_black.txt');
	PlotSurf(13,x,y,H);
end

function kline = PlotData(figId, x,y,H)
	n = size(y,2);
	if n ~= length(H)
		disp('Error...');
		return;
	end

	figure(figId); clf;
	
	% plotting raw data
	subplot(2,1,1);
	hold on;
	clr = jet(n);
	for i=1:n
		plot(x,y(:,i), '.-', 'Color',clr(i,:));
		cH{i} = sprintf('% .2f',H(i));
	end
	hold off;
	xlabel('Energy (eV)');
	ylabel('Intensity');
	legend(cH);
	legend('Location','NorthEast');
	box('on');
	xlim([1,5]);
	ylim([0,1800]);
	
	% lorenzian background subtraction:
%{-
	% background params:
	A = 1600;
	gamma_bk = 1.5;
	x0 = 4.5;
	LorentzianX = @(xx,x0) A*( (gamma_bk./pi) ./ ((xx-x0).^2 + gamma_bk.^2) );
	yLor = LorentzianX(x,x0);
	ny = size(y,2);
	for i = 1:ny
		y(:,i) = y(:,i) - yLor;
	end
%}
	
	% integration
	i30 = max(find(x<=3));
	i35 = max(find(x<=3.5));
	xy30 = [H; sum(y(1:i30,:),1)]';
	xy35 = [H; sum(y(1:i35,:),1)]';
	
	kline = xy30;
	
	subplot(2,1,2);
	hold on;
	plot(xy35(:,1),xy35(:,2), '.-', 'Color',[1 0 0]);
	plot(xy30(:,1),xy30(:,2), '.-', 'Color',[0 0 1]);
	hold off;
	legend('\int up to 3.5 eV','\int up to 3.0 eV');
	legend('Location','North');
	xlabel('H(r.l.u.)');
	ylabel('Integrated Intensity');
	box('on');
	xlim(0.75*[-1,1]);

end

function PlotSurf(figId, x,y,H)
	figure(figId); clf;
	
	mI = y;
	[mH,mE] = meshgrid(H,x');
	
	
	
	pcolor(mH,mE,mI)
%	surf(mH,mE,mI)

	colormap(hot)
	
	shading flat
	axis('tight')
	xlabel('H(r.l.u.)');
	ylabel('Energy (eV)');
	xlim(.5*[-1,1])
end

function ExportKLine(kline, stFile)
	dir = 'export_3ev_woLorentz/';
	if exist(dir,'dir') == 0
		mkdir(dir);
	end
	fid = fopen([dir,stFile],'w');
	fprintf(fid, '% .2f  %16.18g\r\n', kline');
	fclose(fid);
end























