function kline_merged_PRL()
	% Re-creation of experimental v-shape data plot
	clc; addpath('../../_common_');
	%==================================
	figId = 72;	N = 16;		% 8 or 16


	
	%==================================
	
	[dexp_k,dexp_b,dexp_r] = GetDataExper();
	dc = GetDataCalc(N);

	minmaxX = 0.75*[-1,1];
%	minmaxX = [-0.75, 1.5];
%	minmaxX = 1.5*[-1,1];
	
	minmaxY = [-0.07, 1.12];

	figure(figId); clf;
	
    % blank dot to manipulate legend
    hblank = plot(0,0,'.w');
	% grid lines
	clrGrid = 0.6*[1,1,1];
	line(-0.5*[1,1],minmaxY, 'Color',clrGrid, 'LineStyle','--', 'LineWidth',1);
	line( 0.5*[1,1],minmaxY, 'Color',clrGrid, 'LineStyle','--', 'LineWidth',1);
%	line( minmaxX,[0,0], 'Color',clrGrid, 'LineStyle','--', 'LineWidth',1);
	line( minmaxX,[1,1], 'Color',clrGrid, 'LineStyle','--', 'LineWidth',1);
	
	% number of data sets
	ndc = size(dc,1);
	% colors
	clrLine = [...
		126, 34,117; ...
		 61, 72,153; ...
%		128,204,223; ...
		109,181, 45; ...
		239,122, 59; ...
		227, 11, 19; ...
		]./255;

	% plotting theoretical data
	for i = ndc:-1:1
		if i == 2
			lw = 5;
		else
			lw = 3;
		end
		hl(i) = line(dc{i,1}(:,1), dc{i,1}(:,2), ...
			'Color',clrLine(i,:), 'LineWidth',lw, 'LineStyle','-');	
		cLeg{i} = sprintf('%.2f eV', dc{i,2});
	end

	% plotting experimental data
    mlw = 3;
	ms = 14;				% exper. marker size
%	clrBkg = 0.85*[1,1,1];
	clrBkg = [1,1,1];	% white
    hl(ndc+1) = line(dexp_k(:,1),dexp_k(:,2), 'Color','k', 'Marker','o', ...
		'LineStyle','none', 'LineWidth',mlw,'MarkerSize',ms, 'MarkerFaceColor',clrBkg);
	hl(ndc+2) = line(dexp_b(:,1),dexp_b(:,2), 'Color','b', 'Marker','s', ...
		'LineStyle','none', 'LineWidth',mlw,'MarkerSize',ms, 'MarkerFaceColor',clrBkg);
	hl(ndc+3) = line(dexp_r(:,1),dexp_r(:,2), 'Color','r', 'Marker','d', ...
		'LineStyle','none', 'LineWidth',mlw,'MarkerSize',ms, 'MarkerFaceColor',clrBkg);
    cLeg{ndc+1} = ' \theta = 40^o';
	cLeg{ndc+2} = '2\theta= 78^o';
    cLeg{ndc+3} = '2\theta= 68^o';
    
	% axis adjustments:
	FontSize = 20;

	%hleg = legend(hl, cLeg);
    hleg = legend([hblank,hl], ['t_0 =',cLeg]);
	%hleg = legend(hl(1:6), cLeg{1:6});
	set(hleg, 'Location','SouthWest', 'Color','w');
%	box(hleg,'off')

	xlim(minmaxX);
	ylim(minmaxY);
	box('on');
	
	set(gca, 'XTick',-1.5:0.25:1.5);
	set(gca, 'YTick',0:0.1:1);
	set(gca, 'YTickLabel',{'0','','0.2','','0.4','','0.6','','0.8','','1'});
	set(gca, 'FontSize',FontSize, 'LineWidth',2);
	%set(gca, 'YAxisLocation','right');

	xlabel('H (r.l.u.)', 'FontSize',FontSize);
	ylabel('Normalized intensity variation relative to H = 0', 'FontSize',FontSize);

	set(gca,'PlotBoxAspectRatio',[1 1 1]);

	fig2eps(gcf, 'fig2_c.eps');
end
	
function [dexp_k,dexp_b,dexp_r] = GetDataExper()
	% load experimental data:
	dexp_r = load('data_exp_red.txt');
	dexp_b = load('data_exp_blue.txt');
	dexp_k = load('data_exp_black.txt');
	
%{
	% K.A. technique
	minY = 4026.6;	% obtained from Excel
	dexp_r(:,2) = dexp_r(:,2) - minY;
	dexp_b(:,2) = dexp_b(:,2) - minY;
	dexp_k(:,2) = dexp_k(:,2) - minY;
%}
%{-
	% X.L. technique
	minY = 4260.9569427074193;	% lovest value fro red-set at -0.03
	dexp_r(:,2) = dexp_r(:,2) - minY;
	dexp_b(:,2) = dexp_b(:,2) - minY;
	dexp_k(:,2) = dexp_k(:,2) - minY;
%}
	
	maxY = (dexp_r(1,2) + dexp_r(7,2) + dexp_b(1,2) + dexp_b(5,2)) / 4;
	dexp_r(:,2) = dexp_r(:,2) / maxY;
	dexp_b(:,2) = dexp_b(:,2) / maxY;
	dexp_k(:,2) = dexp_k(:,2) / maxY;
end
function [dexp_k,dexp_b,dexp_r] = GetDataExperFlip()
	minY = 4026.6;	% obtained from Excel

	% load experimental data:
	dexp_r = load('data_exp_red.txt');
	dexp_b = load('data_exp_blue.txt');
	dexp_k = load('data_exp_black.txt');
	
	dexp_r(:,2) = dexp_r(:,2) - minY;
	dexp_b(:,2) = dexp_b(:,2) - minY;
	dexp_k(:,2) = dexp_k(:,2) - minY;
	
	maxY = (dexp_r(1,2) + dexp_r(7,2) + dexp_b(1,2) + dexp_b(5,2)) / 4;

	dexp_r(:,2) = dexp_r(:,2) / maxY;
	dexp_b(:,2) = dexp_b(:,2) / maxY;
	dexp_k(:,2) = dexp_k(:,2) / maxY;
	
	dexp_r(:,1) = -1*dexp_r(:,1);
	dexp_b(:,1) = -1*dexp_b(:,1);
	dexp_k(:,1) = -1*dexp_k(:,1);
end
function dc = GetDataCalc(N)
	cFile = { ...
		'kline_t0.100_lambda10.790_beta1.5_Uch-4.0.txt',	0.1; ...
		'kline_t0.900_lambda7.407_beta1.5_Uch-4.0.txt',		0.9; ...
%		'kline_t1.100_lambda4.810_beta1.5_Uch-4.0.txt',		1.1; ...
		'kline_t1.320_lambda3.760_beta1.5_Uch-4.0.txt',		1.32; ...
		'kline_t1.350_lambda3.725_beta1.5_Uch-4.0.txt',		1.35; ...
		'kline_t1.500_lambda3.509_beta1.5_Uch-4.0.txt',		1.5; ...
		};
	
	for i = 1:size(cFile,1)
		xy = load( sprintf('N%02d_kline_data/%s',N,cFile{i,1}) );
		% normalize at Gamma point
%		xy(:,2) = xy(:,2) - xy(xy(:,1)==0.0, 2);	% K.A. version
		xy(:,2) = xy(:,2) - xy(xy(:,1)==-0.03, 2);	% X.L. version
		
		% normalize at max
		xy(:,2) = xy(:,2) / max(xy(:,2));
		
		dc{i,1} = xy;			%#ok
		dc{i,2} = cFile{i,2};	%#ok
	end
end
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	