function kline_merged_PRL_half()
	% Re-creation of experimental v-shape data plot
	clc; addpath('../../_common_');
	%==================================
	figId = 72;	N = 16;		% 8 or 16


	
	%==================================
	
	[dexp_k,dexp_b,dexp_r] = GetDataExper();
	dc = GetDataCalc(N);
	[dexp_k_n,dexp_b_n,dexp_r_n] = GetDataExperFlip();
	
	minmaxY = [-0.05, 1.15];	% experimental
	minmaxX = 0.75*[-1,1];
	ticksX = [-0.75,-0.5,-0.25,0,0.25,0.5,0.75];
	lw = 2;				% exper. line weight
	ms = 8;				% exper. marker size
	figure(figId); clf;
	
	% grid lines
	clrGrid = 0.6*[1,1,1];
	line(-0.5*[1,1],minmaxY, 'Color',clrGrid, 'LineStyle','--', 'LineWidth',1);
	line( 0.5*[1,1],minmaxY, 'Color',clrGrid, 'LineStyle','--', 'LineWidth',1);
	line( minmaxX,[0,0], 'Color',clrGrid, 'LineStyle','--', 'LineWidth',1);
	line( minmaxX,[1,1], 'Color',clrGrid, 'LineStyle','--', 'LineWidth',1);
	
	% number of data sets
	ndc = size(dc,1);
	% colors
	clrLine = [...
		0,   0    0.8; ...
		0,   0.5, 1; ...
		0,   0.6, 0.6; ...
		0.4, 0.8, 0.4; ...
		1,   0.5, 0; ...
		0.8, 0,   0; ...
		];

	% plotting theoretical data
	for i = 1:ndc
		if i == 2
			lw = 4;
		else
			lw = 2;
		end
		hl(i) = line(dc{i,1}(:,1), dc{i,1}(:,2), ...
			'Color',clrLine(i,:), 'LineWidth',lw, 'LineStyle','-');	
		cLeg{i} = sprintf('%g', dc{i,2});
	end

	% plotting experimental data
	hl(ndc+1) = line(dexp_r(:,1),dexp_r(:,2), 'Color','r', 'Marker','d', ...
		'LineStyle','none', 'LineWidth',lw,'MarkerSize',ms, 'MarkerFaceColor','r');
	hl(ndc+2) = line(dexp_b(:,1),dexp_b(:,2), 'Color','b', 'Marker','s', ...
		'LineStyle','none', 'LineWidth',lw,'MarkerSize',ms, 'MarkerFaceColor','b');
	hl(ndc+3) = line(dexp_k(:,1),dexp_k(:,2), 'Color','k', 'Marker','o', ...
		'LineStyle','none', 'LineWidth',lw,'MarkerSize',ms, 'MarkerFaceColor','k');
		
	hl(ndc+1) = line(dexp_r_n(:,1),dexp_r_n(:,2), 'Color','r', 'Marker','d', ...
		'LineStyle','none', 'LineWidth',lw,'MarkerSize',ms, 'MarkerFaceColor','none');
	hl(ndc+2) = line(dexp_b_n(:,1),dexp_b_n(:,2), 'Color','b', 'Marker','s', ...
		'LineStyle','none', 'LineWidth',lw,'MarkerSize',ms, 'MarkerFaceColor','none');
	hl(ndc+3) = line(dexp_k_n(:,1),dexp_k_n(:,2), 'Color','k', 'Marker','o', ...
		'LineStyle','none', 'LineWidth',lw,'MarkerSize',ms, 'MarkerFaceColor','none');
	
	% axis adjustments:
	FontSize = 20;
	
	cLeg{ndc+1} = '68^o';
	cLeg{ndc+2} = '78^o';
	cLeg{ndc+3} = '40^o';
	
	hleg = legend(hl, cLeg);
	%hleg = legend(hl(1:6), cLeg{1:6});
	set(hleg, 'Location','NorthWest', 'Color','w')
%	box(hleg,'off')

	xlim([0,0.75]);
	ylim(minmaxY);
	box('on');
	
	set(gca, 'XTick',ticksX);
	set(gca, 'YTick',0:0.2:1);
	set(gca, 'FontSize',FontSize, 'LineWidth',2);
	set(gca, 'YAxisLocation','right');

	xlabel('H (r.l.u.)', 'FontSize',FontSize);
	ylabel('Intensity (normalized)', 'FontSize',FontSize);

	set(gca,'PlotBoxAspectRatio',[(2/5/0.7) 1 1]);

	fig2eps(gcf, 'fig2_c.eps');
end
	
function [dexp_k,dexp_b,dexp_r] = GetDataExper()
	minY = 4026.6;	% obtained from Excel

	% load experimental data:
	dexp_r = load('data_exp_red.txt');
	dexp_b = load('data_exp_blue.txt');
	dexp_k = load('data_exp_black.txt');
	
	dexp_r(:,2) = dexp_r(:,2) - minY;
	dexp_b(:,2) = dexp_b(:,2) - minY;
	dexp_k(:,2) = dexp_k(:,2) - minY;
	
	maxY = (dexp_r(1,2) + dexp_r(7,2) + dexp_b(1,2) + dexp_b(5,2)) / 4;

	dexp_r(:,2) = dexp_r(:,2) / maxY;
	dexp_b(:,2) = dexp_b(:,2) / maxY;
	dexp_k(:,2) = dexp_k(:,2) / maxY;
end
function [dexp_k,dexp_b,dexp_r] = GetDataExperFlip()
	minY = 4026.6;	% obtained from Excel

	% load experimental data:
	dexp_r = load('data_exp_red.txt');
	dexp_b = load('data_exp_blue.txt');
	dexp_k = load('data_exp_black.txt');
	
	dexp_r(:,2) = dexp_r(:,2) - minY;
	dexp_b(:,2) = dexp_b(:,2) - minY;
	dexp_k(:,2) = dexp_k(:,2) - minY;
	
	maxY = (dexp_r(1,2) + dexp_r(7,2) + dexp_b(1,2) + dexp_b(5,2)) / 4;

	dexp_r(:,2) = dexp_r(:,2) / maxY;
	dexp_b(:,2) = dexp_b(:,2) / maxY;
	dexp_k(:,2) = dexp_k(:,2) / maxY;
	
	dexp_r(:,1) = -1*dexp_r(:,1);
	dexp_b(:,1) = -1*dexp_b(:,1);
	dexp_k(:,1) = -1*dexp_k(:,1);
end
function dc = GetDataCalc(N)
	cFile = { ...
		'kline_t0.100_lambda10.790_beta1.5_Uch-4.0.txt',	0.1; ...
		'kline_t0.900_lambda7.407_beta1.5_Uch-4.0.txt',		0.9; ...
		'kline_t1.100_lambda4.810_beta1.5_Uch-4.0.txt',		1.1; ...
		'kline_t1.320_lambda3.760_beta1.5_Uch-4.0.txt',		1.32; ...
		'kline_t1.350_lambda3.725_beta1.5_Uch-4.0.txt',		1.35; ...
		'kline_t1.500_lambda3.509_beta1.5_Uch-4.0.txt',		1.5; ...
		};
	
	for i = 1:size(cFile,1)
		xy = load( sprintf('N%02d_kline_data/%s',N,cFile{i,1}) );
		% normalize at Gamma point
		xy(:,2) = xy(:,2) - xy(xy(:,1)==0.0, 2);
		% normalize at max
		xy(:,2) = xy(:,2) / max(xy(:,2));
		
		dc{i,1} = xy;			%#ok
		dc{i,2} = cFile{i,2};	%#ok
	end
end
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	