function Uch_Estimation()
	clc;
	
	N = 8;
	t0 = 1.40;
	figId = 100;
	%--------------------------------------------
	data = load( sprintf('DataForUch_N%02d_t%.2f.txt', N, t0) );
	
	% columns: 1-chId, 2-x, 3-iy, 4-Uch, 5-nSum
	Uch = unique(-1*data(:,4));
	minmax_Uch = [min(Uch),max(Uch)];
	minmax_y = [-0.2,1.6];
	
	% base data at CH=0
	z = data(data(:,1)==0 & data(:,2)==0 & data(:,3)==0, 5);
	data_CH0_3pl = z(1);
	z = data(data(:,1)==0 & data(:,2)==1 & data(:,3)==0, 5);
	data_CH0_4pl = z(1);
	
	nUch = length(Uch);
	ch_data = zeros(nUch, 3);
	for i=1:nUch
		ind1 = find(data(:,1)==1 & data(:,4)==-Uch(i));
		ind2 = find(data(:,1)==2 & data(:,4)==-Uch(i));
		ch_data = [ch_data;  ...
			Uch(i), data(ind1,5)-data_CH0_3pl, data(ind2,5)-data_CH0_4pl];
	end
	ch_data = [ch_data, (ch_data(:,2)+ch_data(:,3))/2];
	

	figure(figId); clf; hold on;
	% horiz line at y = 0,1
	plot(minmax_Uch, [0,0],  ':', 'Color',[0 0 0]);
	plot(minmax_Uch, [1,1],  ':', 'Color',[0 0 0]);
	% vert line at chosen Uch
	plot(2.0*[1,1], minmax_y, '-', 'Color',[0 0.8 0]);
	% CH cases:
	h1 = plot(ch_data(:,1), ch_data(:,2), 'o-', 'Color',[0 0 1], 'LineWidth',2);
	h2 = plot(ch_data(:,1), ch_data(:,3), 'o-', 'Color',[1 0 0], 'LineWidth',2);
	hold off;
	xlim(minmax_Uch);
	ylim(minmax_y);
	box('on');
	
	legend([h1,h2], ...
		'CH=1,3 Mn3+', ...
		'CH=2,4 Mn4+', ...
		'Location','NorthWest');

	xlabel('Core-hole potential: |U_{CH}| (eV)');
	ylabel('Electron number change: \Delta n');
	title(sprintf('U_{CH} Estimation (N = %d, t0 = %g)', N, t0));

end