function plot_kline_path()
	clc;
	addpath('../../_common_');
	
	data = GetData();
	kVals = [];
	load('kVals.mat');
	[dataEx_k, dataEx_b, dataEx_r] = GetDataExperiment(0.43);
	
	GL.figId = FigId(50,'k-line-path');
	FontSize = 15;
	minmax_q = [min(kVals(:,1)), max(kVals(:,1))];
	minmax_I = [0,6];
	
	hold on;
	% vertical lines
	kValsVert = kVals(kVals(:,2) == 2, 1);
	for i=1:size(kValsVert,1)
		plot(kValsVert(i,1)*[1,1], minmax_I, '--', 'Color',[.6,.6,.6], 'LineWidth',1.5);
	end
	
	% plot theoretical data
	p1 = plot(data(:,1,1),data(:,2,1),'-', 'Color',[1,0,0], 'LineWidth',2);
	     %plot(data(:,1,6),data(:,2,6),'-.', 'Color',[1,0,0], 'LineWidth',2);
	p2 = plot(data(:,1,2),data(:,2,2),'-', 'Color',[1,.6,0], 'LineWidth',2);
	p3 = plot(data(:,1,3),data(:,2,3),'-', 'Color',[0,.5,0], 'LineWidth',2);
	p4 = plot(data(:,1,4),data(:,2,4),'-', 'Color',[0,.6,1], 'LineWidth',2);
	p5 = plot(data(:,1,5),data(:,2,5),'-', 'Color',[0,0,1], 'LineWidth',2);
		
	% experimental data
	lw = 2;				% exper. line weight
	ms = 6;				% exper. marker size
	line(dataEx_k(:,1),dataEx_k(:,2), ...
		'Color','k', 'Marker','+', 'LineStyle','none', ...
		'LineWidth',lw,'MarkerSize',ms);
	line(dataEx_b(:,1),dataEx_b(:,2), ...
		'Color','b', 'Marker','s', 'LineStyle','none', ...
		'LineWidth',lw,'MarkerSize',ms, 'MarkerFaceColor','b');
	line(dataEx_r(:,1),dataEx_r(:,2), ...
		'Color','r', 'Marker','o', 'LineStyle','none', ...
		'LineWidth',lw,'MarkerSize',ms, 'MarkerFaceColor','r');
	

	xlim(minmax_q);
	ylim(minmax_I);
	
	kMarks = kVals(kVals(:,2) > 0, :);
	set(gca, 'XTick',kMarks(:,1), 'XTickLabel','');
	%set(gca, 'YTick',0:2:8);
	set(gca, 'LineWidth',2);
	set(gca, 'FontSize',FontSize);
	axis('square');
	box('on');
	xlim(minmax_q);
	ylim(minmax_I);
	ylabel('Integrated Intensity (normalized)', 'FontSize',FontSize);
	hold off;
	
	% bottom text
	shft = abs(minmax_I(2)-minmax_I(1)) / 20;
	for i=1:size(kMarks,1)
		str = ['(', Num2Latex(kMarks(i,3),1), ',', Num2Latex(kMarks(i,4),1), ')'];
		FigText(kMarks(i,1), -shft, str, FontSize);
	end	
	% bottom label
	FigText((max(kMarks(:,1))-min(kMarks(:,1)))/2, -2.5*shft, 'Momentum Change', FontSize);
	hold off;


	hl = legend([p1,p2,p3,p4,p5],'100/0','70/30','50/50','30/70','0/100');
	set(hl, 'Location','NorthWest');
	set(hl,'Color','none');
	box(hl, 'off');
	set(hl,'EdgeColor',[1 1 1]);
	%pos = get(hl,'Position'); %pos(2) = pos(2) - 0.1;
	%set(hl,'Position',pos);


	%set(gca,'PlotBoxAspectRatioMode','manual');
	set(gca,'PlotBoxAspectRatio',[1,.5,1]);
%	pos = [0.13+(i-1)*0.15, 0.11, 0.15, 0.75];
%	set(gca, 'Position',pos)
	
	%camva(1.2*camva)
	fig2eps(gcf,'k-line-path')
end

function data = GetData()
	% load Mn3+ data:
	d1 = load('k-line-path-data-t1.1-ch1.txt');
	d2 = load('k-line-path-data-t1.1-ch2.txt');
	d3 = load('k-line-path-data-t1.1-ch3.txt');
	d4 = load('k-line-path-data-t1.1-ch4.txt');

	data = zeros([size(d1),6]);
	x = d1(:,1);
	% calc Mn3+ data:
	y = d1(:,2) + d3(:,2); y = y/y(1);
	data(:,:,1) = [x, y];
	data(:,:,6) = [x, d3(:,2) / d3(1,2)];
	
	% calc avg data: 70%/30%
	data(:,1,2) = x;
	r = 0.7;
	y = r * (d1(:,2) + d3(:,2)) + (1-r) * (d2(:,2) + d4(:,2)); y = y/y(1);
	data(:,2,2) = y;

	% calc avg data: 50%/50%
	data(:,1,3) = x;
	r = 0.5;
	y = r * (d1(:,2) + d3(:,2)) + (1-r) * (d2(:,2) + d4(:,2)); y = y/y(1);
	data(:,2,3) = y;
	
	% calc avg data: 30%/70%
	data(:,1,4) = x;
	r = 0.3;
	y = r * (d1(:,2) + d3(:,2)) + (1-r) * (d2(:,2) + d4(:,2)); y = y/y(1);
	data(:,2,4) = y;

	% calc Mn4+ data:
	data(:,:,5) = [x, d2(:,2)/d2(1,2)];

	% test only:
%	d5 = load('k-line-path-data-t1.1-ch9.txt');	% to check only!
%	data(:,:,5) = [x, d5(:,2)/d5(1,2)];
end
function [dataEx_k, dataEx_b, dataEx_r] = GetDataExperiment(sc)
	dataEx_k = load('data_exp_black.txt');
	dataEx_b = load('data_exp_blue.txt');
	dataEx_r = load('data_exp_red.txt');
	scX = (sqrt(2)*pi/0.5);
	dataEx_k(:,1) = abs( dataEx_k(:,1) * scX );
	dataEx_b(:,1) = abs( dataEx_b(:,1) * scX );
	dataEx_r(:,1) = abs( dataEx_r(:,1) * scX );
	dataEx_k(:,2)	= sc * dataEx_k(:,2) / 1000;
	dataEx_b(:,2)	= sc * dataEx_b(:,2) / 1000;
	dataEx_r(:,2)	= sc * dataEx_r(:,2) / 1000;
	
	%return
	ind = find(dataEx_b(:,1) > sqrt(2)*pi);
	dataEx_b(ind,1) = abs(dataEx_b(ind,1)-2*sqrt(2)*pi);
	
	ind = find(dataEx_r(:,1) > sqrt(2)*pi);
	dataEx_r(ind,1) = abs(dataEx_r(ind,1)-2*sqrt(2)*pi);
end


































