%{
===============================================================================
DESIGNED BY:    Tsezar F. Seman
AFFILIATION:    NJIT University, Physics Department
MODIFIED ON:    08/20/2011
COPYRIGHT:      (c) Tsezar F. Seman. All rights reserved.
PURPOSE:        Function to convert pi-type numerical values to readable text, 
				or LaTeX expression, useful for figures.

				format = [padded_width, dec_precision];
				Defaults: padded_width = 0 => ignore, dec_precision = 2
===============================================================================
%}
function str = Num2Latex(n,bSlash,format)
	if nargin < 2
		bSlash = 1;
	end
	if nargin < 3
		format = [0,2];
	end
	s = sign(n);
	if s == 1
		sig = '';
	else
		sig = '-';
	end
	if bSlash
		sl = '\';
	else
		sl = '';
	end	
	n = abs(n);	
	del = 1e-10;
	
	if abs(n - 0) < del
		str = '0';
	elseif abs(n - pi) < del
		str = [sig sl 'pi'];
	elseif abs(n - pi/2) < del
		str = [sig sl 'pi/2'];
	elseif abs(n - pi/4) < del
		str = [sig sl 'pi/4'];
	elseif abs(n - 3*pi/4) < del
		str = [sig '3' sl 'pi/4'];
	elseif abs(n - pi/3) < del
		str = [sig sl 'pi/3'];
	elseif abs(n - 2*pi/3) < del
		str = [sig '2' sl 'pi/3'];
	elseif abs(n - pi/sqrt(2)) < del
		str = [sig sl 'pi/sqrt2'];
	elseif abs(n - pi/8) < del
		str = [sig sl 'pi/8'];
	elseif abs(n - 3*pi/8) < del
		str = [sig '3' sl 'pi/8'];
	elseif abs(n - 2*pi) < del
		str = [sig '2' sl 'pi'];
	elseif abs(n - 3*pi) < del
		str = [sig '3' sl 'pi'];
	else
		str = sprintf('%%s%%.%if',format(2));
		str = sprintf(str,sig,n);
	end
	strW = sprintf('%% %is',format(1));
	str = sprintf(strW,str);
end