%{
===============================================================================
DESIGNED BY:    Tsezar F. Seman
AFFILIATION:    NJIT University, Physics Department
MODIFIED ON:    08/20/2011
COPYRIGHT:      (c) Tsezar F. Seman. All rights reserved.
PURPOSE:        Class to fascilitate various data tracking, useful for 
				stopping criterias.
===============================================================================
%}
classdef clDataTrack < handle
	properties (SetAccess = private)
		N
		counter
		data
	end
	methods
		function obj = clDataTrack(N)
			obj.N = N;
			obj.counter = ones(1,N);
			obj.data = zeros(50,N);
		end
		function ddd(obj)
			disp(obj.N);
		end
		function Add(obj,dataIn,rangeIn)
			% check for valid input
			if size(dataIn,2) ~= size(rangeIn,2)
				error('ERR clDataTrack: Data size and range mismatch.');
			end
			% check if storage extension is neccesary
			iLast = max(obj.counter(1,rangeIn));
			if iLast > size(obj.data,1)
				obj.data = [obj.data; zeros(50,obj.N)];
			end
			% adding data
			obj.data(iLast,rangeIn) = dataIn;
			obj.counter(1,rangeIn) = obj.counter(1,rangeIn) + 1;
		end
		function dataOut = GetData(obj,rangeIn)
			if nargin < 2
				rangeIn = 1:obj.N;
			end
			iLast = max(obj.counter(1,rangeIn));
			dataOut = obj.data(1:iLast-1,rangeIn);
		end
		% offset can be: ignored or -1,-2,-3,...
		function dataOut = GetLast(obj,rangeIn,offset)
			if nargin < 2
				rangeIn = 1:obj.N;
			end
			if nargin < 3
				offset = 0;
			end
			if offset < 0
				offset = -offset;
			end
			iLast = max(obj.counter(1,rangeIn));
			ind = iLast - offset - 1;
			% if fist data row access, return zeros
			if ind < 1
				z = zeros(1,obj.N);
				dataOut = z(1,rangeIn);
			else
				dataOut = obj.data(ind,rangeIn);
			end
		end
		function nOut = Size(obj,rangeIn)
			if nargin < 2
				rangeIn = 1:obj.N;
			end
			nOut = max(obj.counter(1,rangeIn)) - 1;
		end
	end
end
