%{
===============================================================================
DESIGNED BY:    Tsezar F. Seman
AFFILIATION:    NJIT University, Physics Department
MODIFIED ON:    04/20/2011
COPYRIGHT:      (c) Tsezar F. Seman. All rights reserved.
PURPOSE:        Returns 8 energy values from one k-vector: vk = (kx,ky,kz)
INPUT:
	vk = (kx,ky,kz)
	spin = +/- 1
	bCoulomb = {0,1}
===============================================================================
%}
function E = Bands_E_eg(vk, iSpin, bCoulomb)
	% ACCESS:
	global Eg
	
	if bCoulomb
		E = eig( H_hopping(vk, Eg.C.t0) + ...
			Eg.H_hund(:,:,iSpin) + ...
			Eg.H_jt + ...
			Eg.H_brtng +...
			Eg.H_coloumb(:,:,iSpin) + ...
			Eg.H_shift );
	else
		E = eig( H_hopping(vk, Eg.C.t0) + ...
			Eg.H_hund(:,:,iSpin) + ...
			Eg.H_jt + ...
			Eg.H_brtng +...
			Eg.H_shift );
	end
end
%==========================================================
% Returns 16x16 matrix from one k-vector:
function m16 = H_hopping(vk, t0)
	sqrt3 = sqrt(3);
	Mslice = @(k) (-t0/2) * ...
		[(cos(k(1)) + cos(k(2))),  -sqrt3*(cos(k(1)) - cos(k(2))); ...
		-sqrt3*(cos(k(1)) - cos(k(2))),  3*(cos(k(1)) + cos(k(2)))];
	m16 = blkdiag( ...
		Mslice(vk + [ 0, 0]), ...
		Mslice(vk + [ 1, 0]*pi), ...
		Mslice(vk + [ 0, 1]*pi), ...
		Mslice(vk + [ 1, 1]*pi), ...
		Mslice(vk + [-1,-1]*pi/2), ...
		Mslice(vk + [ 1,-1]*pi/2), ...
		Mslice(vk + [-1, 1]*pi/2), ...
		Mslice(vk + [ 1, 1]*pi/2) );
end
%==========================================================
