%{
===============================================================================
DESIGNED BY:    Tsezar F. Seman
AFFILIATION:    NJIT University, Physics Department
MODIFIED ON:    08/15/2011
COPYRIGHT:      (c) Tsezar F. Seman. All rights reserved.
PURPOSE:        Function creates 2 n-opearators based on one i-space value
				for e_g case.
INPUT:
    vi => one row vector (ix,iy, atom-type)
OUTPUT:
	n_oper(:,:,1) => n_{i,-}
    n_oper(:,:,2) => n_{i,+}
DEPENDANCIES:
    globals:    GL
===============================================================================
%}
function n_oper = Oper_n_eg( vi )
	% ACCESS:
	global GL
	
	nk = size(GL.kPoints, 1);
	NNk = 16*nk;	
	R_mn = GL.R_eg(:,:,vi(3),1);
	R_pl = GL.R_eg(:,:,vi(3),2);
	NN = GL.N^2;
    n_oper = zeros(NNk, NNk, 2);
	for ir = 1:nk
		rr = (ir-1)*16 + 1;
		for ic = 1:nk
			val = exp( 1i * ((GL.kPoints(ic,:) - GL.kPoints(ir,:)) * vi(1,1:2)') ) / NN;
			m16 = val .* exp(1i.*( vi(1) .* GL.kDiff_eg(:,:,1) + vi(2) .* GL.kDiff_eg(:,:,2) ));
			cc = (ic-1)*16 + 1;
			n_oper(rr:rr+15, cc:cc+15, 1) = m16 .* R_mn;		% -, up/down
			n_oper(rr:rr+15, cc:cc+15, 2) = m16 .* R_pl;		% +, up/down
		end
	end
end
%==========================================================
