% Entry point (Hit F5 to run)
%{
===============================================================================
DESIGNED BY:    Tsezar F. Seman
AFFILIATION:    NJIT University, Physics Department
MODIFIED ON:    04/10/2012
COPYRIGHT:      (c) Tsezar F. Seman. All rights reserved.
PURPOSE:        Plotting various RIXS data.
===============================================================================
%}
function run6_plot_rixs(N)
	clc; addpath('_functions_','_common_');
	if nargin < 1
		clear all;
		N = 16;		% must be divisible by 4
	end;
	isSavePDF = 1;
	%--------------------------------------------
	% GENERATE RIXS DATASET:
	CmdTitle(sprintf('LaSrMnO4 PLOTTING RIXS: N = %i', N));
	fprintf('## LOADING CALCULATED RIXS: ... \n');
	LoadCalcRixs(N);

%{
Plot_EHIntensity();
if isSavePDF
	fig2pdf(gcf-2,sprintf('N%02i_CH%i_p4_EH-Intens-Combined_',N,CH));
	fig2pdf(gcf-1,sprintf('N%02i_CH%i_p4_EH-Intens-Combined_',N,CH));
	fig2pdf(gcf,sprintf('N%02i_CH%i_p4_EH-Intens-Combined_',N,CH));
end
return;
%}	
	%--------------------------------------------
	% PLOTTING:
	fprintf('\n## GENERATING PLOTS: ... \n');
	Plot_Energies(0);			% 0-dots, 1-triangles for spin
%	if isSavePDF; fig2pdf(gcf,sprintf('N%02i_p3_E_',N)); end;
return

	Plot_kIntensity();
	if isSavePDF; fig2pdf(gcf,sprintf('N%02i_p4_k-Intens_',N)); end;

	Plot_VShape();
	if isSavePDF; fig2pdf(gcf,sprintf('N%02i_p5_v-Shape_',N)); end;

	Plot_qwContour_1();		% diagonal	
	if isSavePDF; fig2pdf(gcf,sprintf('N%02i_p6_qw-Contour_',N),1); end;

	Plot_qwContourSmooth();
	if isSavePDF; fig2pdf(gcf,sprintf('N%02i_p7_qw-ContourSmooth_',N),1); end;
return
	Plot_EHDistrib();
	if isSavePDF; fig2pdf(gcf,sprintf('N%02i_p8_EH-Distrib_',N)); end;

		%	Plot_qwContour_2();		% small triag
		%	PlotIW_All();	% lots of plots
end



function Plot_EHIntensity()
	global GL
	
	spin = 1;
	RIXS = GL.RIXS(GL.RIXS(:,7)==spin, 1:3);
	
	data = GL.MAP_CH0(:,:,spin);
	nD = size(data,1);
	if spin == 1
		data(:,1) = 1:2:2*nD-1;
	else
		data(:,1) = 2:2:2*nD;
	end
	kPair = unique(data(:,2:3), 'rows');
	nK = size(kPair,1);
	
	% collect all 16 indexes (Hid,Eid) for every k-point
	Ind_EH = zeros(nK, 16);
	for ik = 1:nK
		ind = data(data(:,2)==kPair(ik,1) & data(:,3)==kPair(ik,2), 1);
		if length(ind) ~= 16; fprintf('Error collecting 16 indexes.'); end;
		Ind_EH(ik,:) = ind;
	end
	
% ###TFS TEMP:
%{
%k1 = [0, -pi/4]; k2 = [0, pi/4];
k1 = [-pi/4, 0]; k2 = [pi/4, 0];

ar_id = [data(data(:,2)==k1(1) & data(:,3)==k1(2), 1), ...
	data(data(:,2)==k2(1) & data(:,3)==k2(2), 1)];

ar_id

idEH = 2;
ar = zeros(16,2);
for i=3:16
	id = ar_id(i,:);
	I = RIXS( RIXS(:,idEH) == id(1), 3);
	ar(i,1) = sum(I);
	I = RIXS( RIXS(:,idEH) == id(2), 3);
	ar(i,2) = sum(I);
end
ar
format long
sum(ar,1)
format short
return
%}

	iFermi = data(nD/8,1);
	% collect corresponding intensities from RIXS table
	EH_Irixs = zeros(nK, 16);
	for ib = 1:16
		for ik = 1:nK
			ind = Ind_EH(ik,ib);
			if ind <= iFermi
				Irixs = RIXS( RIXS(:,1) == ind, 3);
				EH_Irixs(ik,ib) = sum(Irixs);
			else
				Irixs = RIXS( RIXS(:,2) == ind, 3);
				EH_Irixs(ik,ib) = sum(Irixs);
			end
		end
	end
	
% ###TFS TEMP:
%{
for ik = 1:nK
	ar(ik,:) = [sum(EH_Irixs(ik,1:2)), ...
		sum(EH_Irixs(ik,3:16))];
end
ar
format long
sum(ar,1)
format short
return
%}
	
	function SqPatch(x,y,dsq,col)
		arX = [x-dsq,x+dsq,x+dsq,x-dsq];
		arY = [y-dsq,y-dsq,y+dsq,y+dsq];
		fill(arX,arY,col, 'Linestyle','none');
	end
	
	dsq = pi / GL.N;	% half-width of the square color patch
	nC = 64;
	cSpin = {'\uparrow','\downarrow'};
	cEH = {'Holes','Electrons'};
	
	
	% INTEGRATED CASES
	GL.figId = FigId(GL.figId,'EH Intensity - Integrated');
	EH_Irixs_Combined = [sum(EH_Irixs(:,1:2),2), sum(EH_Irixs(:,3:16),2)];
	
	cmap = colormap( jet(nC) );
	for ib = 1:2
		subplot(2,1,3-ib);
		hold on;
		minmax_I = [min(EH_Irixs_Combined(:,ib)), max(EH_Irixs_Combined(:,ib))];
		for iPt = 1:nK
			val = EH_Irixs_Combined(iPt, ib);
			q = (val - minmax_I(1)) ./ (minmax_I(2) - minmax_I(1));
			iColor = max( 1, min(nC, round( (nC - 1) * q + 1 )) );
			SqPatch(kPair(iPt,1),kPair(iPt,2), dsq, cmap(iColor,:));
		end
		% draw diamond frame
		frameX = [pi 0 -pi 0 pi]/2; frameY = [0 pi 0 -pi 0]/2;
		plot(frameX, frameY, ':','Color',[0,0,0],  'LineWidth',1);
		% draw line
		frameX = [-pi pi]/2; frameY = [0 0];
		plot(frameX, frameY, ':','Color',[0,0,0],  'LineWidth',1);
		frameX = [0 0]; frameY = [-pi pi]/2;
		plot(frameX, frameY, ':','Color',[0,0,0],  'LineWidth',1);

		hold off;
		title(sprintf('N=%d,CH=%d: %s, %s',GL.N,GL.CH,cEH{ib},cSpin{spin}))
		axis('square');
		axis('off');
		colorbar;
		caxis(minmax_I);
		limits = [-pi/2-dsq, pi/2+dsq];
		xlim(limits);
		ylim(limits);
		set(gca, 'Color','none');
	end
	
	
	
	
	% ALL 2 HOLE CASES
	GL.figId = FigId(GL.figId,'EH Intensity - Holes');
	minmax_I = [min(min(EH_Irixs(:,1:2))), max(max(EH_Irixs(:,1:2)))];
	for ib = 1:2
		subplot(4,4,ib);
		hold on;
		for iPt = 1:nK
			val = EH_Irixs(iPt, ib);
			q = (val - minmax_I(1)) ./ (minmax_I(2) - minmax_I(1));
			iColor = max( 1, min(nC, round( (nC - 1) * q + 1 )) );
			SqPatch(kPair(iPt,1),kPair(iPt,2), dsq, cmap(iColor,:));
		end
		% draw diamond frame
		frameX = [pi 0 -pi 0 pi]/2; frameY = [0 pi 0 -pi 0]/2;
		plot(frameX, frameY, ':','Color',[0,0,0],  'LineWidth',1);
		% draw line
		frameX = [-pi pi]/2; frameY = [0 0];
		plot(frameX, frameY, ':','Color',[0,0,0],  'LineWidth',1);
		frameX = [0 0]; frameY = [-pi pi]/2;
		plot(frameX, frameY, ':','Color',[0,0,0],  'LineWidth',1);

		hold off;
		title(sprintf('Holes: Level %d, %s',ib,cSpin{spin}))
		axis('square');
		axis('off');
		limits = [-pi/2-dsq, pi/2+dsq];
		xlim(limits);
		ylim(limits);
		set(gca, 'Color','none');
	end
	
	% ALL 14 ELECTRON CASES
	GL.figId = FigId(GL.figId,'EH Intensity - Electrons');
	minmax_I = [min(min(EH_Irixs(:,3:16))), max(max(EH_Irixs(:,3:16)))];
	for ib = 3:16
		subplot(4,4,ib);
		hold on;
		for iPt = 1:nK
			val = EH_Irixs(iPt, ib);
			q = (val - minmax_I(1)) ./ (minmax_I(2) - minmax_I(1));
			iColor = max( 1, min(nC, round( (nC - 1) * q + 1 )) );
			SqPatch(kPair(iPt,1),kPair(iPt,2), dsq, cmap(iColor,:));
		end
		% draw diamond frame
		frameX = [pi 0 -pi 0 pi]/2; frameY = [0 pi 0 -pi 0]/2;
		plot(frameX, frameY, ':','Color',[0,0,0],  'LineWidth',1);
		% draw line
		frameX = [-pi pi]/2; frameY = [0 0];
		plot(frameX, frameY, ':','Color',[0,0,0],  'LineWidth',1);
		frameX = [0 0]; frameY = [-pi pi]/2;
		plot(frameX, frameY, ':','Color',[0,0,0],  'LineWidth',1);

		hold off;
		title(sprintf('Electrons: Level %d, %s',ib,cSpin{spin}))
		axis('square');
		axis('off');
		limits = [-pi/2-dsq, pi/2+dsq];
		xlim(limits);
		ylim(limits);
		set(gca, 'Color','none');
	end
end

%==========================================================
% LINE/POINT PLOTTING:
function index = KPtsToIndex(kPts)
	global GL
	
	del = 1e-10;
	index = zeros(size(kPts,1),1);
	for i = 1:size(GL.kPoints,1)
		k = GL.kPoints(i,:);
		tmp = kPts;
		tmp(:,1) = tmp(:,1) - k(1);
		tmp(:,2) = tmp(:,2) - k(2);
		index(sum(abs(tmp),2) < del, 1) = i;
	end
end
function index = KPtsToIndexExt(kPts)
	global GL
	
	del = 1e-10;
	index = zeros(size(kPts,1),1);
	for i = 1:size(GL.kPointsExt,1)
		k = GL.kPointsExt(i,:);
		tmp = kPts;
		tmp(:,1) = tmp(:,1) - k(1);
		tmp(:,2) = tmp(:,2) - k(2);
		index(sum(abs(tmp),2) < del, 1) = GL.kIndexExt(i,1);
	end
end

function Plot_Energies(bSpinSplit)
	% ACCESS:
	global GL
	
	GL.figId = FigId(GL.figId, 'Energy spectrum w/ and w/o Core-Hole.'); hold on;
	
	clrEg = [.2 .8 1];
	clrEgCH = [0 0 1];
	
	n = size(GL.MAP_CH0,1);
	ind_up = GL.MAP_CH0(:,4, 1);
	ind_dn = GL.MAP_CH0(:,4, 2);

	if bSpinSplit == 1
		marker_up = '^';
		marker_dn = 'v';
		marker_size = 5;
	else
		marker_up = '.';
		marker_dn = '.';
		marker_size = 10;
	end
	plot(ind_up,GL.MAP_CH0(:,1,1), marker_up,'MarkerSize',marker_size, 'Color',clrEg, 'MarkerFaceColor',clrEg);
	h0 = plot(ind_dn,GL.MAP_CH0(:,1,2), marker_dn,'MarkerSize',marker_size, 'Color',clrEg, 'MarkerFaceColor',clrEg);
	
	sp = ones(n,1);
	tmp = sortrows([GL.CH1.DATA(:,1,1), sp; GL.CH1.DATA(:,1,2), 2*sp], 1);
	tmp = [tmp, (1:2*n)'];
	ind_up = tmp(tmp(:,2) == 1, 3);
	ind_dn = tmp(tmp(:,2) == 2, 3);
	plot(ind_up,GL.CH1.DATA(:,1,1), marker_up,'MarkerSize',marker_size, 'Color',clrEgCH);
	h1 = plot(ind_dn,GL.CH1.DATA(:,1,2), marker_dn,'MarkerSize',marker_size, 'Color',clrEgCH);
	
	szCH = sprintf('with U_{CH}=%4.1f (eV)', GL.Uch_eg);
	title(sprintf('%s: Energy Profile for H_{eg}, %s',GL.figPref,szCH) );
	ylabel('Energy - E_F (eV)');
	if bSpinSplit == 1
		legend('E_{no CH}^{eg},\uparrow','E_{no CH}^{eg},\downarrow', ...
			'E_{CH}^{eg},\uparrow','E_{CH}^{eg},\downarrow', ...
			'Location','SouthEast');
	else
		% Exclude lines from legend
		set( get(get(h0,'Annotation'),'LegendInformation'), 'IconDisplayStyle','off');
		set( get(get(h1,'Annotation'),'LegendInformation'), 'IconDisplayStyle','off');
		legend('E_{no CH}^{eg}','E_{CH}^{eg}', 'Location','SouthEast');
	end	

	minmax_E = [ ...
		min([GL.MAP_CH0(1,1,1), GL.MAP_CH0(1,1,2), GL.CH1.DATA(1,1,1), GL.CH1.DATA(1,1,2)]), ...
		max([GL.MAP_CH0(n,1,1), GL.MAP_CH0(n,1,2), GL.CH1.DATA(n,1,1), GL.CH1.DATA(n,1,2)]) ];
	fermi = 2*n/8 + 0.5;
	plot([fermi fermi], minmax_E, '--k');
	text(fermi,minmax_E(2)-.1,'occupied', ...
		'Rotation',90, 'HorizontalAlignment','right', 'VerticalAlignment','bottom' );
	text(fermi,minmax_E(2)-.1,'unoccupied', ...
		'Rotation',90, 'HorizontalAlignment','right', 'VerticalAlignment','top' );
	hold off;
	xlim([0,2*n+1]);
	ylim([floor(minmax_E(1)),ceil(minmax_E(2))] );
	box('on');
end

function PlotIW_All()
	global GL

	switch GL.N
		case 4
			gamma = 0.1;	% Lawrentzian gamma
			sigma = 0.17;	% down-scaling parameter
			PlotIW([0, 0],			gamma,sigma);
			PlotIW([pi/2, 0],		gamma,sigma);
		case 8
			gamma = 0.1;	% Lawrentzian gamma
			sigma = 0.06;	% down-scaling parameter
			PlotIW([0, -pi/4],		gamma,sigma);
			PlotIW([pi/4, -pi/4],	gamma,sigma);
			
			PlotIW([-pi/4, 0],		gamma,sigma);
			PlotIW([0, 0],			gamma,sigma);
			PlotIW([pi/4, 0],		gamma,sigma);
			PlotIW([pi/2, 0],		gamma,sigma);
			
			PlotIW([0, pi/4],		gamma,sigma);
			PlotIW([pi/4, pi/4],	gamma,sigma);
		case 12
			gamma = 0.1;	% Lawrentzian gamma
			sigma = 0.05;	% down-scaling parameter
			PlotIW([0, pi/3],	gamma,sigma);
			PlotIW([pi/3, pi/3],gamma,sigma);
			PlotIW([0, 0],		gamma,sigma);
			PlotIW([pi/3, 0],	gamma,sigma);
			PlotIW([pi*2/3, 0],	gamma,sigma);
			PlotIW([pi, 0],		gamma,sigma);
		otherwise
			disp('Plots have not been cofigured for given N.');
	end
end
function PlotIW(del_q, gamma, sigma)
	global GL
	
	szTitle = sprintf('N=%i, CH=%i: RIXS Intensity at del_q = (%6.4f, %6.4f)', ...
		GL.N,GL.CH, del_q(1), del_q(2));
	GL.figId = FigId(GL.figId,szTitle);
	
	% scale factors for squeezing subplots
	PosBot = 0.94; PosHt = 1.27;
	% colors
	clrLor = [0 .8 0];
	clrEg = [0 0 1];
	
	% Cauchy-Lorentz probability density function
	pdfCL = @(x,x0) sigma * (gamma./pi) ./ ((x-x0).^2 + gamma.^2);
	
	minmax_w = [0, ceil( max(GL.RIXS(:,4)) )];
	minmax_I = [0, 1.1*max(GL.RIXS(:,3))];
	
	xCL = minmax_w(1):0.01:minmax_w(2);
	
	% find index of given k-point
	ind_q = find(GL.kPoints(:,1)==del_q(1) & GL.kPoints(:,2)==del_q(2));
	if isempty(ind_q); error('ERR: Point (%g,%g) is not found among kPoints.', del_q); end;
	% find all matching points in the rixs table
	data_wI = GL.RIXS(GL.RIXS(:,8) == ind_q, :);
	
	% spin separation
	data_wI_eg_up = data_wI(data_wI(:,7)==1, :);
	data_wI_eg_dn = data_wI(data_wI(:,7)==2, :);
	
	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	% TOP SUBPLOT
	subplot(3,1,1); hold on;
	
	% plotting distribution
	yCL = 0*xCL;
	for i=1:size(data_wI,1)
		yCL = yCL + data_wI(i,3) .* pdfCL(xCL, data_wI(i,4));
	end
	plot(xCL,yCL,'-', 'Color',clrLor);
	% plotting data points
	plot(data_wI(:,4), data_wI(:,3), 'o','MarkerSize',5, 'Color',clrEg);
	% text labels	
	for i = 1:5
		text(data_wI(i,4),data_wI(i,3), sprintf('  %i:%i',data_wI(i,1),data_wI(i,2)), ...
			'FontSize',7, 'HorizontalAlignment','left', 'VerticalAlignment','bottom');
	end
	text(0.15,0.97*minmax_I(2), sprintf('\\gamma = %g\n\\sigma = %g',gamma,sigma), ...
		'HorizontalAlignment','left', 'VerticalAlignment','top', 'Color',clrLor);
	hold off;
	% setting up the plot	
	xlim(minmax_w);
	ylim(minmax_I);
	title(sprintf('N=%i, CH=%i: RIXS Intensity at \\Delta{q} = (%s,%s)',...
		GL.N,GL.CH, Num2Latex(del_q(1),1),Num2Latex(del_q(2),1) ));
	ylabel('I_{ total}');
	legend('Lorentzian', 'El.-Hole for e_g');

	Pos = get(gca,'Position'); Pos(2) = PosBot*Pos(2); Pos(4) = PosHt*Pos(4); set(gca,'Position',Pos);
	set(gca,'XTickLabel',[], 'Color',[1 0.98 0.9], 'XAxisLocation','top', 'Box','on');
	yt = get(gca, 'YTick');
	set(gca,'YTickLabel',yt,'YTick',yt);
	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	% SUBPLOT #2 - SPIN UP
	subplot(3,1,2); hold on;
	
	% plotting distribution
	yCL = 0*xCL;
	for i=1:size(data_wI_eg_up,1)
		yCL = yCL + data_wI_eg_up(i,3) .* pdfCL(xCL, data_wI_eg_up(i,4));
	end
	plot(xCL,yCL,'-', 'Color',clrLor);
	plot(data_wI_eg_up(:,4), data_wI_eg_up(:,3), 'o','MarkerSize',5, 'Color',clrEg);
	hold off;
	xlim(minmax_w);
	ylim(minmax_I);
	ylabel('I_{ eg,\uparrow}');

	Pos = get(gca,'Position'); Pos(2) = PosBot*Pos(2); Pos(4) = PosHt*Pos(4); set(gca,'Position',Pos);
	set(gca,'XTickLabel',[], 'Box','on');
	set(gca,'YTickLabel',yt,'YTick',yt);
	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	% SUBPLOT #3 - SPIN DOWN
	subplot(3,1,3); hold on;
	
	% plotting distribution
	yCL = 0*xCL;
	for i=1:size(data_wI_eg_dn,1)
		yCL = yCL + data_wI_eg_dn(i,3) .* pdfCL(xCL, data_wI_eg_dn(i,4));
	end
	plot(xCL,yCL,'-', 'Color',clrLor);
	plot(data_wI_eg_dn(:,4), data_wI_eg_dn(:,3), 'o','MarkerSize',5, 'Color',clrEg);
	hold off;
	xlim(minmax_w);
	ylim(minmax_I);
	ylabel('I_{ eg,\downarrow}');
		
	Pos = get(gca,'Position'); Pos(2) = PosBot*Pos(2); Pos(4) = PosHt*Pos(4); set(gca,'Position',Pos);
	set(gca,'XTickMode','auto', 'Box','on');
	set(gca,'YTickLabel',yt,'YTick',yt);
end

function Plot_kIntensity()
	global GL
	
	rixs_sum = sum(GL.RIXS_SUM, 2);
	rixs_sum_ext = rixs_sum(GL.kIndexExt,1);	
	data = [GL.kPoints,rixs_sum;  GL.kPointsExt,rixs_sum_ext];

	szTitle = sprintf('%s: \\int I_{RIXS} in k-Space', GL.figPref);
	
	dsq = pi / GL.N;	% half-width of the square color patch
	
	function SqPatch(x,y,dsq,col)
		arX = [x-dsq,x+dsq,x+dsq,x-dsq];
		arY = [y-dsq,y-dsq,y+dsq,y+dsq];
		fill(arX,arY,col, 'Linestyle','none');
	end
	
	GL.figId = FigId(GL.figId,szTitle);
	minmax_I = [min(data(:,3)), max(data(:,3))];
	
	nK = size(data,1);
	nC = 64;
	cmap = colormap( jet(nC) );
	hold on;
	for iPt = 1:nK
		q = (data(iPt,3) - minmax_I(1)) ./ (minmax_I(2) - minmax_I(1));
		% color
		iColor = max( 1, min(nC, round( (nC - 1) * q + 1 )) );
		SqPatch(data(iPt,1),data(iPt,2), dsq, cmap(iColor,:));
	end
	% draw diamond frame
	frameX = [pi 0 -pi 0 pi]/2;
	frameY = [0 pi 0 -pi 0]/2;
	plot(frameX, frameY, '--','Color',[1,1,1],  'LineWidth',2);
	% draw square frame
	frameX = [pi -pi -pi  pi  pi];
	frameY = [pi  pi -pi -pi  pi];
	plot(frameX, frameY, '--','Color',[1,1,1],  'LineWidth',2);

	hold off;
	colorbar;
	caxis(minmax_I);
	axis('equal');
	xlim([-pi-dsq, pi+dsq]);
	ylim([-pi-dsq, pi+dsq]);
	box('on');
	title(szTitle);
	xlabel('\Delta{q_x}');
	ylabel('\Delta{q_y}');
	
	q = linspace(-pi,pi,9);
	[tickNum,tickLab] = GetLabels( q );
	set(gca, 'XTick',tickNum, 'XTickLabel',tickLab);
	set(gca, 'YTick',tickNum, 'YTickLabel',tickLab);	
	set(gca, 'TickDir','out');
end
function Plot_VShape()
	global GL
	
	rixs_sum = sum(GL.RIXS_SUM, 2);
	rixs_sum_ext = rixs_sum(GL.kIndexExt,1);	
	data = [GL.kPoints,rixs_sum;  GL.kPointsExt,rixs_sum_ext];
	szTitle = sprintf('%s: \\int I_{RIXS} along a line in k-Space', GL.figPref);
	
	GL.figId = FigId(GL.figId,szTitle);
	I_lim = [0,max(data(:,3))];	
	data = sortrows(data, [2, 1]);
	
	% y val at k=(0,0)
	y0 = data(data(:,1)==0 & data(:,2)==0,3);
	yMax = zeros(4,1);
	
	hold on;
	% diagonal kx = ky:
	d = data(data(:,1) - data(:,2) == 0, :);
	x = sign(d(:,1)) .* sqrt(d(:,1).^2 + d(:,2).^2); y = d(:,3);
	plot(x,y, '-*b');
	yMax(1) = max(y);
	% diagonal kx = -ky:
	d = data(data(:,1) + data(:,2) == 0, :);
	x = sign(d(:,1)) .* sqrt(d(:,1).^2 + d(:,2).^2); y = d(:,3);
	plot(x,y, ':*b');
	yMax(2) = max(y);
	% vertical kx = 0:
	d = data(data(:,1) == 0, :);
	x = sign(d(:,2)) .* sqrt(d(:,1).^2 + d(:,2).^2); y = d(:,3);
	plot(x,y, '-*r');
	yMax(3) = max(y);
	% horizontal ky = 0:
	d = data(data(:,2) == 0, :);
	x = sign(d(:,1)) .* sqrt(d(:,1).^2 + d(:,2).^2); y = d(:,3);
	plot(x,y, ':*r');
	yMax(4) = max(y);
	
	hold off;
	cStr{1} = sprintf('R=%.2f; (-\\pi,-\\pi) <-> (\\pi,\\pi)', yMax(1)/y0);
	cStr{2} = sprintf('R=%.2f; (-\\pi,\\pi) <-> (\\pi,-\\pi)', yMax(2)/y0);
	cStr{3} = sprintf('R=%.2f; (0,-\\pi) <-> (0,\\pi)', yMax(3)/y0);
	cStr{4} = sprintf('R=%.2f; (-\\pi,0) <-> (\\pi,0)', yMax(4)/y0);
	
	legend(cStr{1},cStr{2},cStr{3},cStr{4},	'Location','SouthEast');
	title(szTitle);
	xlabel('Parametrized k_{xy}');
	ylabel('\Sigma I_{RIXS}');
	xlim([-1,1]*pi*sqrt(2));
	ylim(I_lim);
	box('on');
end

function Plot_qwContour_1()
	global GL
	
	% kVals cols: 1 - parametric x value, 2 - vertical line flag, 3:4 - actual k-value
	sq = sqrt(2);
	p2 = pi/2;
	p4 = pi/4;
	p8 = pi/8;
	switch GL.N
		case 4
			gammaQ = 0.15;
			gammaW = 0.3;
			
			% diagonal line
			kVals = [ ...
				[-pi*sq,		1,		-pi, -pi]; ...
				[-p2*sq,		0,		-pi/2, -pi/2]; ...
				[0,				1,		0, 0]; ...
				[p2*sq,			0,		pi/2, pi/2]; ...
				[pi*sq,			1,		pi, pi] ];
			PlotRixsContribQW_Fig(kVals,gammaQ,gammaW);
		case 8
			gammaQ = 0.15;
			gammaW = 0.3;
			
			% diagonal line
			kVals = [ ...
				[-pi*sq,		1,		-pi, -pi]; ...
				[-3*p4*sq,		0,		-3*pi/4, -3*pi/4]; ...
				[-p2*sq,		0,		-pi/2, -pi/2]; ...
				[-p4*sq,		0,		-pi/4, -pi/4]; ...
				[0,				1,		0, 0]; ...
				[p4*sq,			0,		pi/4, pi/4]; ...
				[p2*sq,			0,		pi/2, pi/2]; ...
				[3*p4*sq,		0,		3*pi/4, 3*pi/4]; ...
				[pi*sq,			1,		pi, pi] ];
			PlotRixsContribQW_Fig(kVals,gammaQ,gammaW);
			%{
			kVals = [ ...
				[-pi*sq,		1,		-pi, pi]; ...
				[-3*p4*sq,		0,		-3*pi/4, 3*pi/4]; ...
				[-p2*sq,		0,		-pi/2, pi/2]; ...
				[-p4*sq,		0,		-pi/4, pi/4]; ...
				[0,				1,		0, 0]; ...
				[p4*sq,			0,		pi/4, -pi/4]; ...
				[p2*sq,			0,		pi/2, -pi/2]; ...
				[3*p4*sq,		0,		3*pi/4, -3*pi/4]; ...
				[pi*sq,			1,		pi, -pi] ];
			PlotRixsContribQW_Fig(kVals,gammaQ,gammaW);
			%}
		case 16
			gammaQ = 0.15;
			gammaW = 0.3;
			
			% diagonal line
			kVals = [ ...
				[-sq*8*p8,		1,		-8*p8, -8*p8]; ...
				[-sq*7*p8,		0,		-7*p8, -7*p8]; ...
				[-sq*6*p8,		0,		-6*p8, -6*p8]; ...
				[-sq*5*p8,		0,		-5*p8, -5*p8]; ...
				[-sq*4*p8,		0,		-4*p8, -4*p8]; ...
				[-sq*3*p8,		0,		-3*p8, -3*p8]; ...
				[-sq*2*p8,		0,		-2*p8, -2*p8]; ...
				[-sq*1*p8,		0,		-1*p8, -1*p8]; ...
				[0, 			1,		0, 0]; ...
				[sq*1*p8,		0,		1*p8, 1*p8]; ...
				[sq*2*p8,		0,		2*p8, 2*p8]; ...
				[sq*3*p8,		0,		3*p8, 3*p8]; ...
				[sq*4*p8,		0,		4*p8, 4*p8]; ...
				[sq*5*p8,		0,		5*p8, 5*p8]; ...
				[sq*6*p8,		0,		6*p8, 6*p8]; ...
				[sq*7*p8,		0,		7*p8, 7*p8]; ...
				[sq*8*p8,		1,		8*p8, 8*p8] ];
			PlotRixsContribQW_Fig(kVals,gammaQ,gammaW);
	end
end
function Plot_qwContour_2()
	global GL
	
	% kVals cols: 1 - parametric x value, 2 - vertical line flag, 3:4 - actual k-value
	sq2 = sqrt(2);
	p2 = pi/2;
	switch GL.N
		case 8
			gammaQ = 0.15;
			gammaW = 0.3;
			
			% small triang
			kVals = [ ...
				[-p2,				1,		pi/2, 0]; ...
				[-p2/2,				0,		pi/4, 0]; ...
				[0,					1,		0, 0]; ...
				[p2/2,				0,		0, pi/4]; ...
				[p2,				1,		0, pi/2]; ...				
				[p2+p2*sq2/2,		0,		pi/4, pi/4]; ...
				[p2+p2*sq2,			1,		pi/2, 0]; ...
				[p2+3*p2*sq2/2,		0,		pi/4, -pi/4]; ...
				[p2+2*p2*sq2,		1,		0, -pi/2] ];
			PlotRixsContribQW_Fig(kVals,gammaQ,gammaW);
		case 16
			disp('....Not defined!');
	end
end
function PlotRixsContribQW_Fig(kVals,gammaQ,gammaW)
	global GL
	
	LorentzianQ = @(qq,q0) ( (gammaQ./pi) ./ ((qq-q0).^2 + gammaQ.^2) );
	LorentzianW = @(ww,w0) ( (gammaW./pi) ./ ((ww-w0).^2 + gammaW.^2) );
	
	nk = size(kVals,1);	
	minmax_q = [kVals(1,1), kVals(nk,1)] + [-pi/16, pi/16];
	%minmax_w = [floor( min(GL.RIXS(:,4)) ), ceil( max(GL.RIXS(:,4)) )];
	minmax_w = [0, ceil( max(GL.RIXS(:,4)) )];
	[qq,ww] = meshgrid(linspace(minmax_q(1),minmax_q(2),200), ...
		linspace(minmax_w(1),minmax_w(2),200));
	
	% k-point indexes to use in search for RIXS values
	kInd = KPtsToIndex(kVals(:,3:4)) + KPtsToIndexExt(kVals(:,3:4));
	
	peaksXY = zeros(nk,3);
	zz = zeros(size(qq));
	for ik = 1:nk
		% collect all intensities and energies for a given k-point
		IWrixs = GL.RIXS(GL.RIXS(:,8) == kInd(ik), 3:4);
		zz_tmp = zeros(size(qq));
		for iw = 1:size(IWrixs,1)
			zz_tmp = zz_tmp + IWrixs(iw,1) .* LorentzianW(ww,IWrixs(iw,2));
		end
		zz_tmp = zz_tmp .* LorentzianQ(qq,kVals(ik,1));
		% finding the peak
		[c,ir] = max(zz_tmp);
		[c,ic] = max(c);
		peaksXY(ik,:) = [qq(ir(ic),ic), ww(ir(ic),ic), c];
		zz = zz + zz_tmp;
	end
	maxZ = max(max(zz));
	zz = zz ./ maxZ;
	
	szTitle = sprintf('%s: Combined I_{ RIXS} Contribution ( I_{ RIXS}^{ max} = %5.3f)',GL.figPref,maxZ);
	GL.figId = FigId(GL.figId,szTitle);
	
	pcolor(qq,ww,zz);
	caxis([0, 1]);
	axis('tight');	%'equal'
	colormap(hot(128));	
	shading('flat');
	%colorbar('Position',[0.92,0.7,0.015,0.2]); % , 'XColor',[.9 .9 .9],'YColor',[.9 .9 .9]
	colorbar
	
	% draw vertical white lines with text
	hold on;
	clrWhite = [1 1 1];
	clrPeaks = [0 .6 0];
	clrText = [1 .8 0];
	% Gamma text
	text(kVals(1,1)+0.2,minmax_w(2)-.05, sprintf('Lorentzian:\n\\gamma_q = %g\n\\gamma_{\\omega} = %g',gammaQ,gammaW ), ...
		'Color',clrText, 'HorizontalAlignment','left', 'VerticalAlignment','top');
	for ik = 1:nk
		if kVals(ik,2) == 1
			% vertical line
			plot([kVals(ik,1), kVals(ik,1)], [minmax_w(1), minmax_w(2)], ':', 'Color',clrWhite);
			% Delta q text
			str = sprintf('(%s, %s) ', Num2Latex(kVals(ik,3),1),Num2Latex(kVals(ik,4),1) );
			text(kVals(ik,1),minmax_w(2), str, ...
				'Color',clrWhite, 'Rotation',90,'HorizontalAlignment','right', 'VerticalAlignment','bottom');
		end
	end
	
	peaksXY = peaksXY(peaksXY(:,3) ~= 0,:);
	% draw spline connecting the peaks
%	xx = linspace(min(peaksXY(:,1)),max(peaksXY(:,1)),150);
%	yy = spline(peaksXY(:,1),peaksXY(:,2),xx);
%	plot(xx,yy,'-', 'Color',clrPeaks);
	% plot dots
	plot(peaksXY(:,1),peaksXY(:,2),'--x', 'Color',clrPeaks, 'MarkerSize',8);
	hold off;
	
	% axis matters
	title(szTitle);
	xlabel('Parameterized \Delta{q}');
	ylabel('Energy change \Delta{\omega} (eV)');
	set(gca, 'TickDir','out');
	axis('square');
end

function Plot_qwContourSmooth()
	global GL
	
	% kVals cols: 1 - parametric x value, 2 - vertical line flag, 3:4 - actual k-value
	sq = sqrt(2);
	p2 = pi/2;
	p4 = pi/4;
	p8 = pi/8;
	switch GL.N
		case 4
			gammaW = 0.3;
			
			% diagonal line
			kVals = [ ...
				[-pi*sq,		1,		-pi, -pi]; ...
				[-p2*sq,		0,		-pi/2, -pi/2]; ...
				[0,				1,		0, 0]; ...
				[p2*sq,			0,		pi/2, pi/2]; ...
				[pi*sq,			1,		pi, pi] ];
			PlotRixsContribSmoothQW_Fig(kVals,gammaW);
		case 8
			gammaW = 0.3;
			
			% diagonal line
			kVals = [ ...
				[-pi*sq,		1,		-pi, -pi]; ...
				[-3*p4*sq,		0,		-3*pi/4, -3*pi/4]; ...
				[-p2*sq,		1,		-pi/2, -pi/2]; ...
				[-p4*sq,		0,		-pi/4, -pi/4]; ...
				[0,				1,		0, 0]; ...
				[p4*sq,			0,		pi/4, pi/4]; ...
				[p2*sq,			1,		pi/2, pi/2]; ...
				[3*p4*sq,		0,		3*pi/4, 3*pi/4]; ...
				[pi*sq,			1,		pi, pi] ];
			PlotRixsContribSmoothQW_Fig(kVals,gammaW);
		case 16
			gammaW = 0.3;
			
			% diagonal line
			kVals = [ ...
				[-sq*8*p8,		1,		-8*p8, -8*p8]; ...
				[-sq*7*p8,		0,		-7*p8, -7*p8]; ...
				[-sq*6*p8,		0,		-6*p8, -6*p8]; ...
				[-sq*5*p8,		0,		-5*p8, -5*p8]; ...
				[-sq*4*p8,		1,		-4*p8, -4*p8]; ...
				[-sq*3*p8,		0,		-3*p8, -3*p8]; ...
				[-sq*2*p8,		0,		-2*p8, -2*p8]; ...
				[-sq*1*p8,		0,		-1*p8, -1*p8]; ...
				[0, 			1,		0, 0]; ...
				[sq*1*p8,		0,		1*p8, 1*p8]; ...
				[sq*2*p8,		0,		2*p8, 2*p8]; ...
				[sq*3*p8,		0,		3*p8, 3*p8]; ...
				[sq*4*p8,		1,		4*p8, 4*p8]; ...
				[sq*5*p8,		0,		5*p8, 5*p8]; ...
				[sq*6*p8,		0,		6*p8, 6*p8]; ...
				[sq*7*p8,		0,		7*p8, 7*p8]; ...
				[sq*8*p8,		1,		8*p8, 8*p8] ];
			PlotRixsContribSmoothQW_Fig(kVals,gammaW);
	end
end
function PlotRixsContribSmoothQW_Fig(kVals,gammaW)
	global GL
	
	Ny = 200;
	Nx = 200;
	
	LorentzianW = @(ww,w0) ( (gammaW./pi) ./ ((ww-w0).^2 + gammaW.^2) );
	
	nk = size(kVals,1);	
	minmax_q = [kVals(1,1), kVals(nk,1)];
	%minmax_w = [floor( min(GL.RIXS(:,4)) ), ceil( max(GL.RIXS(:,4)) )];
	minmax_w = [0, ceil( max(GL.RIXS(:,4)) )];
	xCont = linspace(minmax_q(1), minmax_q(2), Nx);
	yCont = linspace(minmax_w(1), minmax_w(2), Ny);
	
	% k-point indexes to use in search for RIXS values
	kInd = KPtsToIndex(kVals(:,3:4)) + KPtsToIndexExt(kVals(:,3:4));
	
	% collect all w-sets as smooth Lorentzians
	w_set = zeros(Ny, nk);
	for ik = 1:nk
		% collect all intensities and energies for a given k-point
		IWrixs = GL.RIXS(GL.RIXS(:,8) == kInd(ik), 3:4);
		I_tmp = zeros(size(yCont));
		for iw = 1:size(IWrixs,1)
			I_tmp = I_tmp + IWrixs(iw,1) .* LorentzianW(yCont,IWrixs(iw,2));
		end
		w_set(:,ik) = I_tmp';
	end
	
	% interpolate horizontally
	[qq,ww] = meshgrid(xCont, yCont);
	zz = zeros(size(qq));
	q_param = kVals(:,1)';
	
%dq = abs(q_param(2) - q_param(1))/2;
%q_param = [q_param(1)-dq, q_param, q_param(nk)+dq];
%w_set = [w_set(:,1), w_set, w_set(:,nk)];
%n_extend = 2;
%n_extend = 0;

	for iw = 1:Ny
		I_tmp = w_set(iw,:);
%		p = polyfit(q_param, I_tmp, nk-1 + n_extend);
%		zz(iw,:) = polyval(p, xCont);
		
		zz(iw,:) = spline(q_param,I_tmp, xCont);
	end
	maxZ = max(max(zz));
	zz = zz ./ maxZ;

	% plot contour map
	szTitle = sprintf('%s: Integrated I_{ RIXS} Contribution',GL.figPref);
	GL.figId = FigId(GL.figId,szTitle);
	pcolor(qq,ww,zz);
	caxis([0, 1]);
	axis('tight');	%'equal'
	colormap(hot(128));
	shading('flat');
	%colorbar('Position',[0.92,0.7,0.015,0.2]); % , 'XColor',[.9 .9 .9],'YColor',[.9 .9 .9]
	colorbar

	% Gamma text
	hold on;
	clrText = [1 .8 0];
	text(kVals(1,1)+0.2,minmax_w(2)-.05, sprintf('\\gamma_{\\omega} = %g',gammaW ), ...
		'Color',clrText, 'HorizontalAlignment','left', 'VerticalAlignment','top');
	
	% axis matters
	title(szTitle);
	h = xlabel('Parameterized \Delta{q}');
	ylabel('Energy change \Delta{\omega} (eV)');
	set(gca, 'TickDir','out');
	
	% better x-axis
	x_Tick = kVals(:,1)';
	clrBlk = [0 0 0];
	for i = 1:nk
		if kVals(i,2) == 1
			sLabel = sprintf('(%s,%s)', Num2Latex(kVals(i,3),1), Num2Latex(kVals(i,4),1) );
			text(kVals(i,1),minmax_w(1)-0.08, sLabel, 'FontSize',9, 'Color',clrBlk,...
				'HorizontalAlignment','center', 'VerticalAlignment','top');
		end
	end
	set(gca,'XTick',x_Tick, 'XTickLabel','');
	% shift down the xlabel
	pos = get(h,'Position');
	pos = pos .* [1 1.5 1];
	set(h,'Position',pos);
	
	hold off;
	axis('square');
end

function Plot_EHDistrib()
	global GL
	
	gamma = 0.05;
	spin = 1;	% 1-up or 2-down
	
	rixs = GL.RIXS(GL.RIXS(:,7)==spin, 1:4);
	energ = GL.MAP_CH0(:,1,spin);
	
	% COLLECT DATA
	nE = size(energ, 1);
	nF = round(nE / 8);	% Fermi threshhold
	data = zeros(nE,2);
	spoff = [1, 0];
	for iE = 1:nE
		E = energ(iE);
		if iE <= nF
			I = sum( rixs(rixs(:,1) == (2*iE-spoff(spin)), 3) );
			data(iE,:) = [I, E];
		else
			I = sum( rixs(rixs(:,2) == (2*iE-spoff(spin)), 3) );
			data(iE,:) = [I, E];
		end
	end
	minmaxI = [0, 1.1*max(data(:,1))];
%	minmaxI(2) = max(2e-3, minmaxI(2));
	minmaxE = [floor(min(data(:,2))), ceil(max(data(:,2)))];
	
	%[sum(data(1:nF,1)), sum(data(nF+1:nE,1))]
	
	% DISPLAY PLOT
	szTitle = sprintf('N=%i: Electron and Hole Distribution',GL.N);
	GL.figId = FigId(GL.figId,szTitle);
	hold on;
	for iE = 1:nE
		plot([0,data(iE,1)], [data(iE,2),data(iE,2)], '-b');
	end
	plot(data(1:nF,1), data(1:nF,2), 'ob', ...
		'MarkerSize',10, 'MarkerFaceColor',[1 .7 0]);
	plot(data(nF+1:nE,1), data(nF+1:nE,2), 'ob', ...
		'MarkerSize',10, 'MarkerFaceColor',[.8 .5 .9]);
	% Fermi line
	yF = (data(nF,2)+data(nF+1,2))/2;
	plot(minmaxI, [yF,yF], '--', 'Color',[.2,.8,.2]);
	
	% Lorentzian:
	pdfCL = @(y,y0) (gamma./pi) ./ ((y-y0).^2 + gamma.^2);
	yCL = linspace(minmaxE(1),minmaxE(2),400);
	xCL = 0*yCL;
	for iE=1:nE
		xCL = xCL + data(iE,1) .* pdfCL(yCL, data(iE,2));
	end
	sigma = minmaxI(2)/max(xCL);
	xCL = xCL * sigma;	
	plot(xCL,yCL, '-r', 'LineWidth',2);
	text(0.98*minmaxI(2),0.98*minmaxE(2),sprintf('\\gamma = %.2f',gamma),...
		'Color','r', 'HorizontalAlignment','right', 'VerticalAlignment','top');
	
	hold off;
	box on;
	set(gca,'YGrid','on')
	xlim(minmaxI);
	ylim(minmaxE);
	title(szTitle);
	xlabel('Total Intensity Contribution');
	ylabel('Energy (eV)');
end
%==========================================================
% FIGURE AID:
function [tickNum,tickLab] = GetLabels(val)
	tickNum = sort(val);
	for i=1:length(tickNum)
		tickLab{i} = Num2Latex(tickNum(i),0);	%#ok
	end
end
%==========================================================
% SAVING/LOADING:
function LoadCalcRixs(N)
	% ACCESS to overwrite
	global GL
	
	path = sprintf('_N%02i_data_/_RIXS_',N);
	load(sprintf('%s/N%02i_CalcRixs.mat',path,N));
	
	GL.figId = 30;
	GL.figPref = sprintf('N = %d',GL.N);
end
%==========================================================







































