% Entry point (Hit F5 to run)
%{
===============================================================================
DESIGNED BY:    Tsezar F. Seman
AFFILIATION:    NJIT University, Physics Department
MODIFIED ON:    04/10/2012
COPYRIGHT:      (c) Tsezar F. Seman. All rights reserved.
PURPOSE:        Plotting various RIXS data.
===============================================================================
%}
function run6_plot_rixs__PRL(N)
	clc; addpath('_functions_','_common_');
	if nargin < 1
		clear all;
		N = 16;		% must be divisible by 4
	end;

	isSaveEPS = 1;
	%--------------------------------------------
	% GENERATE RIXS DATASET:
	CmdTitle(sprintf('LaSrMnO4 PRL EPS: N = %i', N));
	fprintf('## LOADING CALCULATED RIXS: ... \n');
	LoadCalcRixs(N);

	%--------------------------------------------
	% SPECIAL PLOTTING FOR EPS REPORT:
	
%{
	Plot_kMap__EPS();
	if isSaveEPS; fig2eps(gcf,'k-intensity-avg'); end;
%}
%{
	Plot_kMap_Quater__EPS();
	if isSaveEPS; fig2eps(gcf,'k-intensity-quater'); end;
%}
%{-
	Plot_kMap_Half__EPS();
	if isSaveEPS; fig2eps(gcf,'k-intensity-half'); end;
%}
%{
	Plot_kLine__EPS();
	if isSaveEPS; fig2eps(gcf,'v-shape-avg'); end;
	if isSavePDF
		fig2pdf(gcf, sprintf('N%02d_v-shape__PRL_',N));
	end
%}
% CONTOUR:
%{
	kNodes = [0,0;  pi,pi];  kMask = [1,1];
	kVals = CollectPathPoints(N,kNodes,kMask);
	Plot_Contour1__EPS(kVals);
	if isSaveEPS
		fig2eps(gcf,'fig2_b.eps', 0);	% eps base: 0-vector, 1-image
	end
return;
%}
%{
	Plot_qwContourSmooth__EPS();	% Contour Smooth
	if isSaveEPS; fig2eps(gcf,'contour-avg', 0); end;	% eps base: 0-vector, 1-image
%}
	
	% DO NOT USE:
	%Plot_kIntensitySmooth__EPS();	
end
%==========================================================
% LINE/POINT PLOTTING:
function index = KPtsToIndex(kPts)
	global GL
	
	del = 1e-10;
	index = zeros(size(kPts,1),1);
	for i = 1:size(GL.kPoints,1)
		k = GL.kPoints(i,:);
		tmp = kPts;
		tmp(:,1) = tmp(:,1) - k(1);
		tmp(:,2) = tmp(:,2) - k(2);
		index(sum(abs(tmp),2) < del, 1) = i;
	end
end
function index = KPtsToIndexExt(kPts)
	global GL
	
	del = 1e-10;
	index = zeros(size(kPts,1),1);
	for i = 1:size(GL.kPointsExt,1)
		k = GL.kPointsExt(i,:);
		tmp = kPts;
		tmp(:,1) = tmp(:,1) - k(1);
		tmp(:,2) = tmp(:,2) - k(2);
		index(sum(abs(tmp),2) < del, 1) = GL.kIndexExt(i,1);
	end
end

%==========================================================
% FIGURE AID:
function [tickNum,tickLab] = GetLabels(val)
	tickNum = sort(val);
	for i=1:length(tickNum)
		tickLab{i} = Num2Latex(tickNum(i),0);	%#ok
	end
end
%==========================================================
% SAVING/LOADING:
function LoadCalcRixs(N)
	% ACCESS to overwrite
	global GL
	
	path = sprintf('_N%02i_data_/_RIXS_',N);
	load(sprintf('%s/N%02i_CalcRixs.mat',path,N));
	
	GL.figId = 60;
	GL.figPref = sprintf('N = %d',GL.N);
end

function [t0,lambda,beta,Uch] = GetParams()
	global GL
	
	t0 = GL.C.t0;
	lambda = GL.C.lambda;
	beta = GL.C.beta;
	Uch = GL.C.Uch;
end
%==========================================================

%==========================================================
% SPECIAL EPS ROUTINES:
function Plot_kIntensitySmooth__EPS()
	global GL
	
	rixs_sum = sum(GL.RIXS_SUM, 2);
	rixs_sum_ext = rixs_sum(GL.kIndexExt,1);	
	data = [GL.kPoints, rixs_sum;  GL.kPointsExt, rixs_sum_ext ];
	szTitle = sprintf('%s: \\Sigma I_{RIXS} in k-Space', GL.figPref);
	
	% intensity re-normalization
	data(:,3) = data(:,3) ./ max(data(:,3));
	minmax_I = [min(data(:,3)), max(data(:,3))];
	disp(minmax_I)
	
	% 2D interpolation
	dd = sortrows(data,[2,1]);	
	x = unique(data(:,1));
	y = unique(data(:,2));
	[xx,yy] = meshgrid(x,y);
	zz = reshape(dd(:,3),length(y),length(y))';

	[xxi,yyi] = meshgrid( linspace(-pi,pi,200) );
	zzi = interp2(xx,yy,zz,xxi,yyi,'bicubic');
	%zzi = interp2(xx,yy,zz,xxi,yyi,'nearest');

	GL.figId = FigId(GL.figId,szTitle);
	
	% color contour plot
	hold on;
	pcolor(xxi,yyi,zzi);
	shading('flat');
	colormap(jet(128));

	% draw diamond frame
	frameX = [pi 0 -pi 0 pi]/2; frameY = [0 pi 0 -pi 0]/2;
	plot(frameX, frameY, '--','Color',[1,1,1], 'LineWidth',2);
		
	hold off;	
	hcb = colorbar;
	caxis(minmax_I);
	axis('equal');
	xlim([-pi,pi]);
	ylim([-pi,pi]);
	box('on');	
	% axis adjustments
	FontSize = 25;
	q = linspace(-pi,pi,9);
	set(gca, 'XTick',q, 'XTickLabel','');
	set(gca, 'YTick',q, 'YTickLabel','');
	tickLabels = {'-0.5';'';'-0.25';'';'0';'';'0.25';'';'0.5'};
	set(gca, 'XTickLabel',tickLabels);
	set(gca, 'YTickLabel',tickLabels);
	xlabel('H (r.l.u.)', 'FontSize',FontSize);
	ylabel('K (r.l.u.)', 'FontSize',FontSize);
	
	% side right text
	FigText(pi+1.6, 0, 'Calculated Intensity', FontSize,90);
	
	set(gca, 'TickDir','out', 'FontSize',FontSize);
	set(gca, 'LineWidth',2);
	% colorbar adjustments
	set(hcb, 'YTick',[.4,.6,.8,1]);
	set(hcb, 'LineWidth',2);

	camva(1.2*camva)
end

function Plot_kMap__EPS()
	global GL
	
	rixs_sum = sum(GL.RIXS_SUM, 2);
	minI = min(rixs_sum);
	rixs_sum = rixs_sum / minI;	% re-normalize
	rixs_sum_ext = rixs_sum(GL.kIndexExt,1);	
	data = [GL.kPoints,rixs_sum; GL.kPointsExt,rixs_sum_ext ];

	szTitle = sprintf('%s: \\Sigma I_{RIXS} in k-Space', GL.figPref);
	
	FontSize = 23;
	dsq = pi / GL.N;	% half-width of the square color patch
	
	function SqPatch(x,y,dsq,col)
		arX = [x-dsq,x+dsq,x+dsq,x-dsq];
		arY = [y-dsq,y-dsq,y+dsq,y+dsq];
		fill(arX,arY,col, 'Linestyle','none');
	end
	
	GL.figId = FigId(GL.figId,szTitle);
	
%	[I_scale, I_strSuff] = DataScale( max(data(:,3)) );
%	data(:,3) = I_scale * data(:,3);
	minmax_I = [min(data(:,3)), max(data(:,3))];
	
	nK = size(data,1);
	nC = 64;
	cmap = colormap( jet(nC) );
	hold on;
	for iPt = 1:nK
		q = (data(iPt,3) - minmax_I(1)) ./ (minmax_I(2) - minmax_I(1));
		% color
		iColor = max( 1, min(nC, round( (nC - 1) * q + 1 )) );
		SqPatch(data(iPt,1),data(iPt,2), dsq, cmap(iColor,:));
	end
	% draw diamond frame
	frameX = [pi 0 -pi 0 pi]/2;
	frameY = [0 pi 0 -pi 0]/2;
	plot(frameX, frameY, '--','Color',[1 1 1],  'LineWidth',2);
	% black outline
	frameX = [pi -pi -pi  pi  pi];
	frameY = [pi  pi -pi -pi  pi];
	plot(frameX, frameY, '-','Color',[0 0 0],  'LineWidth',2);
	hold off;
	
	hcb = colorbar;
	caxis(minmax_I);	
	axis('equal');
	xlim(pi*[-1,1]);
	ylim(pi*[-1,1]);
	box('on');
	
	q = linspace(-pi,pi,9);
	[tickNum,tickLab] = GetLabels( q );
	tickLabels = {'-0.5';'';'-0.25';'';'0';'';'0.25';'';'0.5'};
	set(gca, 'XTick',tickNum, 'XTickLabel',tickLabels);
	set(gca, 'YTick',tickNum, 'YTickLabel',tickLabels);
	xlabel('H (r.l.u.)', 'FontSize',FontSize);
	ylabel('K (r.l.u.)', 'FontSize',FontSize);

	% side right text
%	FigText(pi+dsq+1.3, 0, 'Normalized Calculated Intensity', FontSize,90);
	
	set(gca, 'TickDir','out', 'FontSize',FontSize);
	set(gca, 'LineWidth',2);

%	set(hcb, 'YTick',[.4,.6,.8,1]);
	set(hcb, 'LineWidth',2);
	
	camva(1.2*camva)
end
function Plot_kMap_Quater__EPS()
	global GL
	
	rixs_sum = sum(GL.RIXS_SUM, 2);
	minI = min(rixs_sum);
	rixs_sum = rixs_sum / minI;	% re-normalize
	rixs_sum_ext = rixs_sum(GL.kIndexExt,1);	
	data = [GL.kPoints,rixs_sum; GL.kPointsExt,rixs_sum_ext ];

	szTitle = sprintf('%s: \\Sigma I_{RIXS} in k-Space', GL.figPref);
	
	FontSize = 23;
	dsq = pi / GL.N;	% half-width of the square color patch
	
	function SqPatch(x,y,dsq,col)
		arX = [x-dsq,x+dsq,x+dsq,x-dsq];
		arY = [y-dsq,y-dsq,y+dsq,y+dsq];
		fill(arX,arY,col, 'Linestyle','none');
	end
	
	GL.figId = FigId(GL.figId,szTitle);
	
	minmax_I = [min(data(:,3)), max(data(:,3))];
	
	nK = size(data,1);
	nC = 64;
	cmap = colormap( jet(nC) );
	hold on;
	for iPt = 1:nK
		q = (data(iPt,3) - minmax_I(1)) ./ (minmax_I(2) - minmax_I(1));
		% color
		iColor = max( 1, min(nC, round( (nC - 1) * q + 1 )) );
		SqPatch(data(iPt,1),data(iPt,2), dsq, cmap(iColor,:));
	end
	% black outline
	frameX = [pi 0 0  pi  pi];
	frameY = [pi  pi 0 0  pi];
	plot(frameX, frameY, '-','Color',[0 0 0],  'LineWidth',4);
	hold off;
	

	caxis(minmax_I);
	axis('equal');
	xlim([0,pi]);
	ylim([0,pi]);
	box('on');
	
	set(gca, 'XTick',[]);
	set(gca, 'YTick',[]);
	
	set(gca, 'TickDir','out', 'FontSize',FontSize);
	set(gca, 'LineWidth',2);

	camva(1.2*camva)
end
function Plot_kMap_Half__EPS()
	global GL
	
	rixs_sum = sum(GL.RIXS_SUM, 2);
	minI = min(rixs_sum);
	rixs_sum = rixs_sum / minI;	% re-normalize
	rixs_sum_ext = rixs_sum(GL.kIndexExt,1);	
	data = [GL.kPoints,rixs_sum; GL.kPointsExt,rixs_sum_ext ];

	szTitle = sprintf('%s: \\Sigma I_{RIXS} in k-Space', GL.figPref);
	
	FontSize = 23;
	dsq = pi / GL.N;	% half-width of the square color patch
	
	function SqPatch(x,y,dsq,col)
		arX = [x-dsq,x+dsq,x+dsq,x-dsq];
		arY = [y-dsq,y-dsq,y+dsq,y+dsq];
		fill(arX,arY,col, 'Linestyle','none');
	end
	
	GL.figId = FigId(GL.figId,szTitle);
	
	minmax_I = [min(data(:,3)), max(data(:,3))];
	
	nK = size(data,1);
	nC = 64;
	cmap = colormap( jet(nC) );
	hold on;
	for iPt = 1:nK
		q = (data(iPt,3) - minmax_I(1)) ./ (minmax_I(2) - minmax_I(1));
		% color
		iColor = max( 1, min(nC, round( (nC - 1) * q + 1 )) );
		SqPatch(data(iPt,1),data(iPt,2), dsq, cmap(iColor,:));
	end
	% black outline
	frameX = [pi -pi -pi  pi  pi];
	frameY = [pi  pi 0 0  pi];
	plot(frameX, frameY, '-','Color',[0 0 0],  'LineWidth',4);
	hold off;
	

	caxis(minmax_I);
	axis('equal');
	xlim([-pi,pi]);
	ylim([0,pi]);
	box('on');
	
	set(gca, 'XTick',-pi:pi/2:pi);
	set(gca, 'YTick',0:pi/2:pi);
    set(gca, 'XTickLabel',{'-0.5','','0','','0.5'});
    set(gca, 'YTickLabel',{'0','','0.5'});
    
    xlabel('H (r.l.u.)', 'FontSize',FontSize);
    ylabel('K (r.l.u.)', 'FontSize',FontSize);
	
	set(gca, 'TickDir','out', 'FontSize',FontSize);
	set(gca, 'LineWidth',2);
%    set(gca, 'YAxisLocation','right');

	camva(1.2*camva)
end

function Plot_kLine__EPS()
	global GL
	
	rixs_sum = sum(GL.RIXS_SUM, 2);
	maxI = max(rixs_sum);
	rixs_sum = rixs_sum / maxI;	% re-normalize
	rixs_sum_ext = rixs_sum(GL.kIndexExt,1);	
	data = [GL.kPoints,rixs_sum; GL.kPointsExt,rixs_sum_ext ];
	
	szTitle = sprintf('%s: \\Sigma I_{RIXS} along lines in k-Space', GL.figPref);
	
	FontSize = 20;
	
	GL.figId = FigId(GL.figId,szTitle);
	I_lim = [0,max(data(:,3))];
	data = sortrows(data, [2, 1]);
	
	[yScale,yStrSuff] = DataScale(I_lim(2));
	I_lim(2) = ceil(yScale * I_lim(2));
	
	hold on;
	% diagonal kx = ky:
	d = data(data(:,1) - data(:,2) == 0, :);
	x = sign(d(:,1)) .* sqrt(d(:,1).^2 + d(:,2).^2);
	y = yScale * d(:,3);
	
%	plot(x,y, '*b',  'LineWidth',3);	%, 'Marker','o','MarkerSize',12,'MarkerFaceColor','k'
	
	% smooth spline	
%	xxSp = linspace(x(1),x(length(x)), 100);
%	yySp = spline(x,y,xxSp);
	
	dx = x(2)-x(1); sh = 2*sqrt(2)*pi; nx = length(x);
	x1 = [x(1:nx-1)-sh; x; x(2:nx)+sh];
	y1 = [y(1:nx-1); y; y(2:nx)];	
	xxSp = linspace(x1(1),x1(length(x1)), 301);
	yySp = spline(x1,y1,xxSp);
	plot(xxSp,yySp, '-k',  'LineWidth',3);
	
plot(x,y, '*b',  'LineWidth',3)

% TEMP:
%{-
	xk = (sqrt(2)*pi/.5)*[-0.47	-0.33	-0.19	-0.03	0.19	0.35	0.53];
	% up to 3.0 eV
	%yk = [0.982721325	0.91078812	0.539595657	0.147366935	0.488794402	0.834393227	1.017278675];
	% up to 3.5 eV
	yk = [0.9803274	0.897979496	0.539024254	0.155830379	0.483635347	0.843703307	1.0196726];
	plot(xk,yk, '*r', 'LineWidth',4);
%}
	
	
% SPECIAL EXPORT:
%{
x_out = (0.5/(sqrt(2)*pi)) * x;
y_out = (8000/1.15) * y;
data_out = [x_out, y_out];
data_out2 = [data_out(13:16,1)-1.0, data_out(13:16,2); ...
			data_out; ...
			data_out(2:5,1)+1.0, data_out(2:5,2)];

nSPL = size(data_out2,1);
xSPL_out = linspace(data_out2(1,1), data_out2(nSPL,1), 257);
ySPL_out = spline(data_out2(:,1), data_out2(:,2), xSPL_out);
data_out3 = [xSPL_out', ySPL_out'];

save('_EPS_/data_theor_x0.50.txt', 'data_out', '-ascii', '-double');
save('_EPS_/data_theor_x0.75.txt', 'data_out2', '-ascii', '-double');
save('_EPS_/data_theor_x0.75_smooth.txt', 'data_out3', '-ascii', '-double');
%}
	
	csvData = [x, y/yScale]';
	
	%ylabel(sprintf('Integrated Intensity (%s)',yStrSuff), 'FontSize',FontSize);
	ylabel(sprintf('Integrated Intensity'), 'FontSize',FontSize);
	pi2 = pi*sqrt(2);
	xlim([-1,1]*pi2*3/2);
	ylim(I_lim);
	
ylim([0,1.1]);
	
	box('on');
	set(gca, 'FontSize',FontSize);	
	set(gca, 'XTick',[-pi2,-pi2/2,0,pi2/2,pi2], 'XTickLabel','');
	set(gca, 'LineWidth',2);
	axis('square');	
	
	% bottom text
	shft = abs(I_lim(2)-I_lim(1)) / 30;
	FigText(-pi2,-shft,		'(-\pi,-\pi)', FontSize);
	FigText(-pi2/2,-shft,	'(-\pi/2,-\pi/2)', FontSize);
	FigText(   0,-shft,		'0', FontSize);
	FigText( pi2/2,-shft,	'(\pi/2,\pi/2)', FontSize);
	FigText( pi2,-shft,		'(\pi,\pi)', FontSize);
	
	FigText(  0, -2.5*shft,	'Momentum Change', FontSize);
	
	%{
	text(-4.2876, 2.94, '(a)', 'FontSize',FontSize, 'Color',[0 0 0], ...
		'HorizontalAlignment','left', 'VerticalAlignment','top', ...
		 'BackgroundColor',[1 1 1], 'EdgeColor',[0 0 0], 'LineWidth',2, 'Margin',5);
	%}
	hold off;
	
	camva(1.2*camva)
	
%{-
	% extract SPLINE data
	[t0,lambda,beta,Uch] = GetParams();
	suf = sprintf('_t%0.3f_lambda%0.3f_beta%0.1f_Uch%.1f', t0,lambda,beta,Uch);
	
	MakeDir('_EPS_');
	file = sprintf('_EPS_/kline%s.txt',suf);
	fid = fopen(file, 'w');
	dataSmooth = [(0.5/(sqrt(2)*pi))*xxSp; yySp/min(yySp)];
	dataSmooth = dataSmooth(:, dataSmooth(1,:)>=-0.8 & dataSmooth(1,:)<=0.8 );
	fprintf(fid, '% .4f  %.15f\r\n', dataSmooth);
	fclose(fid);
	fprintf('    * File [%s] have been generated.\n',file);
%}
end
function [tickNum,tickLab] = GetColorbarLabels__EPS(vMin,vMax)
	if mod(vMin,0.5) == 0
		ar = vMin;
	else
		ar = vMin - mod(vMin,0.5) + 0.5;
	end
	tickNum = [];
	for i = ar:0.5:vMax
		tickNum = [tickNum,i];
	end
	for i = 1:length(tickNum)
		tickLab{i} = sprintf('%0.1f',tickNum(i));
	end
end


function kVals = CollectPathPoints(N,kNodes,kMask)
	nNodes = size(kNodes,1);
	dsq = 2*pi/N;
	t = 0;	% starting parametric value
	kVals = [];
	for i = 1:nNodes-1
		k1 = kNodes(i,:);
		k2 = kNodes(i+1,:);	
		nx = abs(k2(1)-k1(1)) / dsq;  dx = sign((k2(1)-k1(1))) * dsq;
		if nx == 0; dx = 0; end;
		ny = abs(k2(2)-k1(2)) / dsq;  dy = sign((k2(2)-k1(2))) * dsq;
		if ny == 0; dy = 0; end;
		Lsq = sqrt( dx^2 + dy^2 );
		nPts = max(nx,ny);
		kPath = zeros(nPts,4);
		kPath(1,:) = [t, kMask(i), k1(1), k1(2)];
		for j = 2:nPts
			t = t + Lsq;
			kx = kPath(j-1,3)+dx;
			ky = kPath(j-1,4)+dy;
			kPath(j,:) = [t, 0, kx, ky];
		end
		t = t + Lsq;
		if i == nNodes-1;
			kPath = [kPath;   t, kMask(i+1), k2(1), k2(2)];
		end
		kVals = [kVals; kPath];
	end
end
function Plot_Contour1__EPS(kVals)
	global GL
	
	gammaW = 0.6;
	FontSize = 25;
	Ny = 400;
	Nx = 200;
	
	LorentzianW = @(ww,w0) ( (gammaW./pi) ./ ((ww-w0).^2 + gammaW.^2) );
	
	nk = size(kVals,1);	
	minmax_q = [kVals(1,1), kVals(nk,1)];
	
	%minmax_w = [floor( min(GL.RIXS(:,4)) ), ceil( max(GL.RIXS(:,4)) )];
	%minmax_w = [0, ceil( max(GL.RIXS(:,4)) )];
	minmax_w = [0, 5];
	xCont = linspace(minmax_q(1), minmax_q(2), Nx);
	yCont = linspace(minmax_w(1), minmax_w(2), Ny);

	% k-point indexes to use in search for RIXS values
	kInd = KPtsToIndex(kVals(:,3:4)) + KPtsToIndexExt(kVals(:,3:4));
	
	% collect all w-sets as smooth Lorentzians
	w_set = zeros(Ny, nk);
	for ik = 1:nk
		% collect all intensities and energies for a given k-point
		IWrixs = GL.RIXS(GL.RIXS(:,8) == kInd(ik), 3:4);
		I_tmp = zeros(size(yCont));
		for iw = 1:size(IWrixs,1)
			I_tmp = I_tmp + IWrixs(iw,1) .* LorentzianW(yCont,IWrixs(iw,2));
		end
		w_set(:,ik) = I_tmp';
	end
	
	% interpolate horizontally
	[qq,ww] = meshgrid(xCont, yCont);
	zz = zeros(size(qq));
	q_param = kVals(:,1)';
	for iw = 1:Ny
		I_tmp = w_set(iw,:);
		zz(iw,:) = spline(q_param,I_tmp, xCont);
	end
	
[c1,i1] = max(zz,[],2);
[c2,i2] = max(c1);

Imax = c2;
ix = i1(i2);
iy = i2;
qVal = qq(iy,ix);
wVal = ww(iy,ix);

fprintf('Max E = %.4f\n',wVal);
	
	
	maxZ = max(max(zz));
	zz = zz ./ maxZ;
	fprintf('Max Irixs = %.2e\n',maxZ);
	
	% plot contour map
	szTitle = sprintf('%s: Integrated I_{ RIXS} Contribution',GL.figPref);
	GL.figId = FigId(GL.figId,szTitle);
	hold on;
	pcolor(qq,ww,zz);
	caxis([0, 1]);
	axis('tight');	%'equal'
	colormap(hot(128));
	shading('flat');
    
    % colorbar adjustments
%	hcb = colorbar;
%	set(hcb, 'LineWidth',2);
	hold off;
    
	% axis matters
    xlim(minmax_q);
	ylim(minmax_w);
    
    xlabel('H (r.l.u.)', 'FontSize',FontSize);
	ylabel('Energy (eV)', 'FontSize',FontSize);
	set(gca, 'TickDir','out', 'FontSize',FontSize);
	
    pi2 = pi*sqrt(2);
	set(gca, 'XTick',[0,pi2/2,pi2], 'XTickLabel',{'0','','0.5'});
	set(gca, 'YTick',0:8);
	set(gca, 'LineWidth',2);

	box('on')
	set(gca,'PlotBoxAspectRatio',[.3 1 1])

%	camva(1.2*camva)
end

function Plot_qwContourSmooth__EPS()
	global GL
	
	% kVals cols: 1 - parametric x value, 2 - vertical line flag, 3:4 - actual k-value
	sq = sqrt(2);
	p2 = pi/2;
	p4 = pi/4;
	p8 = pi/8;
	switch GL.N
		case 4
			gammaW = 0.3;
			
			% diagonal line
			kVals = [ ...
				[-pi*sq,		1,		-pi, -pi]; ...
				[-p2*sq,		0,		-pi/2, -pi/2]; ...
				[0,				1,		0, 0]; ...
				[p2*sq,			0,		pi/2, pi/2]; ...
				[pi*sq,			1,		pi, pi] ];
			PlotRixsContribSmoothQW_Fig__EPS__EPS(kVals,gammaW);
		case 8
			gammaW = 0.3;
			
			% diagonal line
			kVals = [ ...
				[-6*p4*sq,		0,		pi/2, pi/2]; ...		% extended
				[-5*p4*sq,		0,		3*pi/4, 3*pi/4]; ...	% extended
				[-pi*sq,		1,		-pi, -pi]; ...
				[-3*p4*sq,		0,		-3*pi/4, -3*pi/4]; ...
				[-p2*sq,		1,		-pi/2, -pi/2]; ...
				[-p4*sq,		0,		-pi/4, -pi/4]; ...
				[0,				1,		0, 0]; ...
				[p4*sq,			0,		pi/4, pi/4]; ...
				[p2*sq,			1,		pi/2, pi/2]; ...
				[3*p4*sq,		0,		3*pi/4, 3*pi/4]; ...
				[pi*sq,			1,		pi, pi]; ...
				[5*p4*sq,		0,		-3*pi/4, -3*pi/4]; ...	% extended
				[6*p4*sq,		0,		-pi/2, -pi/2]; ...		% extended
				];
			PlotRixsContribSmoothQW_Fig__EPS(kVals,gammaW);
		case 16
			gammaW = 0.6;
			
			% diagonal line
			kVals = [ ...
				[-sq*12*p8,		0,		4*p8, 4*p8]; ...	% extended
				[-sq*11*p8,		0,		5*p8, 5*p8]; ...	% extended
				[-sq*10*p8,		0,		6*p8, 6*p8]; ...	% extended
				[-sq*9*p8,		0,		7*p8, 7*p8]; ...	% extended
				[-sq*8*p8,		1,		-8*p8, -8*p8]; ...
				[-sq*7*p8,		0,		-7*p8, -7*p8]; ...
				[-sq*6*p8,		0,		-6*p8, -6*p8]; ...
				[-sq*5*p8,		0,		-5*p8, -5*p8]; ...
				[-sq*4*p8,		1,		-4*p8, -4*p8]; ...
				[-sq*3*p8,		0,		-3*p8, -3*p8]; ...
				[-sq*2*p8,		0,		-2*p8, -2*p8]; ...
				[-sq*1*p8,		0,		-1*p8, -1*p8]; ...
				[0, 			1,		0, 0]; ...
				[sq*1*p8,		0,		1*p8, 1*p8]; ...
				[sq*2*p8,		0,		2*p8, 2*p8]; ...
				[sq*3*p8,		0,		3*p8, 3*p8]; ...
				[sq*4*p8,		1,		4*p8, 4*p8]; ...
				[sq*5*p8,		0,		5*p8, 5*p8]; ...
				[sq*6*p8,		0,		6*p8, 6*p8]; ...
				[sq*7*p8,		0,		7*p8, 7*p8]; ...
				[sq*8*p8,		1,		8*p8, 8*p8]; ...
				[sq*9*p8,		0,		-7*p8, 7*p8]; ...	% extended
				[sq*10*p8,		0,		-6*p8, 6*p8]; ...	% extended
				[sq*11*p8,		0,		-5*p8, 5*p8]; ...	% extended
				[sq*12*p8,		0,		-4*p8, 4*p8]; ...	% extended
				];
			PlotRixsContribSmoothQW_Fig__EPS(kVals,gammaW);
	end
end
function PlotRixsContribSmoothQW_Fig__EPS(kVals,gammaW)
	global GL
	
	FontSize = 20;
	Ny = 200;
	Nx = 200;
	
	LorentzianW = @(ww,w0) ( (gammaW./pi) ./ ((ww-w0).^2 + gammaW.^2) );
	
	nk = size(kVals,1);	
	minmax_q = [kVals(1,1), kVals(nk,1)];

	%minmax_w = [floor( min(GL.RIXS(:,4)) ), ceil( max(GL.RIXS(:,4)) )];
	%minmax_w = [0, ceil( max(GL.RIXS(:,4)) )];
	minmax_w = [0, 5];
	xCont = linspace(minmax_q(1), minmax_q(2), Nx);
	yCont = linspace(minmax_w(1), minmax_w(2), Ny);

	% k-point indexes to use in search for RIXS values
	kInd = KPtsToIndex(kVals(:,3:4)) + KPtsToIndexExt(kVals(:,3:4));
	
	% collect all w-sets as smooth Lorentzians
	w_set = zeros(Ny, nk);
	for ik = 1:nk
		% collect all intensities and energies for a given k-point
		IWrixs = GL.RIXS(GL.RIXS(:,8) == kInd(ik), 3:4);
		I_tmp = zeros(size(yCont));
		for iw = 1:size(IWrixs,1)
			I_tmp = I_tmp + IWrixs(iw,1) .* LorentzianW(yCont,IWrixs(iw,2));
		end
		w_set(:,ik) = I_tmp';
	end
	
	% interpolate horizontally
	[qq,ww] = meshgrid(xCont, yCont);
	zz = zeros(size(qq));
	q_param = kVals(:,1)';
	for iw = 1:Ny
		I_tmp = w_set(iw,:);
		zz(iw,:) = spline(q_param,I_tmp, xCont);
	end
	maxZ = max(max(zz));
	zz = zz ./ maxZ;

	% plot contour map
	szTitle = sprintf('%s: Integrated I_{ RIXS} Contribution',GL.figPref);
	GL.figId = FigId(GL.figId,szTitle);
	hold on;
	pcolor(qq,ww,zz);
	caxis([0, 1]);
	axis('tight');	%'equal'
	colormap(hot(128));
	shading('flat');
	hcb = colorbar;
xlim(minmax_q);
ylim(minmax_w);

	% axis matters
	ylabel('Energy (eV)', 'FontSize',FontSize);
	set(gca, 'TickDir','out', 'FontSize',FontSize);
	
	% colorbar adjustments
	set(hcb, 'LineWidth',2);
	set(hcb, 'YTick',[0,0.25,0.5,0.75,1], ...
		'YTickLabel',{'0';'';'0.5';'';'1'})
	
	pi2 = pi*sqrt(2);
%	set(gca, 'XTick',[-pi2,-pi2/2,0,pi2/2,pi2], 'XTickLabel','');
	set(gca, 'XTick',[-3*pi2/2,-pi2,-pi2/2,0,pi2/2,pi2,3*pi2/2], ...
		'XTickLabel',{'-0.75';'-0.5';'-0.25';'0';'0.25';'0.5';'0.75'});
	set(gca, 'YTick',0:8, ...
		'YTickLabel',{'0';'';'2';'';'4';'';'6';'';'8'});
	xlabel('H (r.l.u.)');
	set(gca, 'LineWidth',2);
	%axis('square');
	set(gca,'PlotBoxAspectRatio',[1 .5 1])
	box('on')
	% bottom text
%	shft = abs(minmax_w(2)-minmax_w(1)) / 20;
%	FigText(-pi2,-shft,		'(-\pi,-\pi)', FontSize);
%	FigText(-pi2/2,-shft,	'(-\pi/2,-\pi/2)', FontSize);
%	FigText(   0,-shft,		'0', FontSize);
%	FigText( pi2/2,-shft,	'(\pi/2,\pi/2)', FontSize);
%	FigText( pi2,-shft,		'(\pi,\pi)', FontSize);
%	FigText(  0,-2.5*shft,	'Momentum Change', FontSize);
	% side right text
%	FigText(minmax_q(2)+3.1, (minmax_w(2)-minmax_w(1))/2, 'Normalized Calculated Intensity', FontSize,90);
	
	% vertical white lines
%	line(-pi2*[1,1],minmax_w, 'Color',[1 1 1], 'LineStyle','--', 'LineWidth',2);
%	line( pi2*[1,1],minmax_w, 'Color',[1 1 1], 'LineStyle','--', 'LineWidth',2);
	
	% vertical black lines
%	line(-1.5*pi2*[1,1],minmax_w, 'Color',[0 0 0], 'LineStyle','-', 'LineWidth',2);
%	line( 1.5*pi2*[1,1],minmax_w, 'Color',[0 0 0], 'LineStyle','-', 'LineWidth',3);
	
	%{
	% fig (b) label
	text(-4.2876, 7.8769, '(b)', 'FontSize',FontSize, 'Color',[0 0 0], ...
		'HorizontalAlignment','left', 'VerticalAlignment','top', ...
		 'BackgroundColor',[1 1 1], 'EdgeColor',[0 0 0], 'LineWidth',2, 'Margin',5);
	%}
	hold off;
	
	camva(1.2*camva)
end
%==========================================================
