% Entry point (Hit F5 to run)
%{
===============================================================================
DESIGNED BY:    Tsezar F. Seman
AFFILIATION:    NJIT University, Physics Department
MODIFIED ON:    05/24/2012
COPYRIGHT:      (c) Tsezar F. Seman. All rights reserved.
PURPOSE:		Calculate and plot density of states (DOS), projected states -
				nenh, and electron-hole distribution.
===============================================================================
%}
function run7_dos_nenh(N)
	clc; addpath('_common_');
	if nargin < 1
		clear all;
		N = 16;		% must be divisible by 4
	end;
	
	t0 = GetVal_t0(N);
	iBndSt3 = [];
	iBndSt4 = [];
	switch t0
		case 0.1
			shiftE = 4.64902595;
		case 0.6
			shiftE = 4.50117621;
		case 0.9
			shiftE = 4.17279306;
			iBndSt3 = [1,65];
			iBndSt4 = [1,65,129];		%  193,194
		case 1.1
			shiftE = 3.73921945;
		case 1.3
			shiftE = 3.61694785;
		case 1.32
			shiftE = 3.61736508;
		case 1.33
			shiftE = 3.61938530;
		case 1.35
			shiftE = 3.62362752;
		case 1.40
			shiftE = 3.62999964;
		case 1.5
			shiftE = 3.64416614;
			iBndSt3 = [1,193];
			iBndSt4 = [1,2,65,66,67,193,194];
		otherwise
			shiftE = 0.0;
	end
	
	CH = [1,2];
	spin = [1,2];
	figId = 1;
	%minmax_E = [-5,12];
	minmax_E = [-5,5];

	isSavePDF = 0;
	isSaveEPS = 1;
	%============================================
	% PRE-RIXS DATA - PROJECTED STATES
	%============================================
	% load data
	path = sprintf('_N%02i_data_/_RIXS_',N);
	CH0 = struct([]);  CH1 = struct([]);  CH2 = struct([]);
	load(sprintf('%s/N%02i_CH%i.mat',path,N,CH(2))); CH2 = CH1;
	load(sprintf('%s/N%02i_CH%i.mat',path,N,CH(1)));
	load(sprintf('%s/N%02i_CH0.mat',path,N));
	data = Get_DOS(CH0.H_eg, CH1.H_eg, CH2.H_eg, shiftE);
    
	%============================================
	% SETTING GLOBAL
	%============================================
	global PAR
	PAR.N = N;
	PAR.t0 = t0;
	PAR.data = data;
	PAR.minmax_E = minmax_E;
	PAR.figId = figId;
	PAR.iBndSt3 = iBndSt3;
	PAR.iBndSt4 = iBndSt4;
	
%{
	% Energy
	figId = FigId(figId,'Energies');	
	Plot_Energies(data,t0);
	return;
%}
	
%{-
	% Density of States Data:
	gamma = 0.05;
%gamma = 0.1;
	figId = FigId(figId,'Dens. of States');
	[dataDOS,dataDOSMn3,dataDOSMn4] = Plot_DOS(data, N, gamma, minmax_E);
	if isSavePDF; fig2pdf(gcf,sprintf('p1_N%02i_DOS_',N)); end;
	
	figId = FigId(figId,'Dens. of States Difference');
	Plot_DOS_diff(dataDOS,dataDOSMn3,dataDOSMn4, minmax_E, t0);
    if isSaveEPS; fig2eps(gcf,sprintf('dos-diff-t%0.2f',t0)); end;
%}
%return

%{-
	% Projected States:
	gamma = 0.05;
	W = abs(data(1,1));
	
	figId = FigId(figId,'Proj. States Mn3+');
	stCase = 'Mn^{3+}';
	[dataPrMn3_L,dataPrMn3_R] = ...
		PlotProjections(CH0.H_eg(:,:,spin(1)), CH1.H_eg(:,:,spin(1)), spin(1), N, minmax_E, gamma, stCase, shiftE);
		PlotProjections(CH0.H_eg(:,:,spin(2)), CH1.H_eg(:,:,spin(2)), spin(2), N, minmax_E, gamma, stCase, shiftE);
	if isSavePDF; fig2pdf(gcf,sprintf('p2_N%02i_ProjSt_Mn3_',N)); end;
SpecialData(sprintf('t0 = %g, Mn3+',t0), W, dataPrMn3_R);
	
	
	figId = FigId(figId,'Proj. States Mn4+');
	stCase = 'Mn^{4+}';
	[dataPrMn4_L,dataPrMn4_R] = ...
		PlotProjections(CH0.H_eg(:,:,spin(1)), CH2.H_eg(:,:,spin(1)), spin(1), N, minmax_E, gamma, stCase, shiftE);
		PlotProjections(CH0.H_eg(:,:,spin(2)), CH2.H_eg(:,:,spin(2)), spin(2), N, minmax_E, gamma, stCase, shiftE);
	if isSavePDF; fig2pdf(gcf,sprintf('p3_N%02i_ProjSt_Mn4_',N)); end;
SpecialData(sprintf('t0 = %g, Mn4+',t0), W, dataPrMn4_R);
%}
%return

	%============================================
	% POST-RIXS DATA - E-H DISTRIBUTION
	%============================================
	%clearvars -except N CH spin figId isSavePDF
%{-
	% load data
	gamma = 0.05;
	figId = FigId(figId,'E-H Distrib.');
	path = sprintf('_N%02i_data_/_RIXS_',N);
	
	load(sprintf('%s/N%02i_CalcRixs.mat',path,N));
	[dataEHMn3_up_L,dataEHMn3_up_R] = ...
		Get_EHDistrib(GL, spin(1), gamma, shiftE);
	[dataEHMn3_dn_L,dataEHMn3_dn_R] = ...
		Get_EHDistrib(GL, spin(2), gamma, shiftE);	
	Plot_EHDistrib(dataEHMn3_up_L,dataEHMn3_up_R, dataEHMn3_dn_L,dataEHMn3_dn_R, ...
		N, CH(1), minmax_E, gamma);

	load(sprintf('%s/N%02i_CalcRixs.mat',path,N));
	[dataEHMn4_up_L,dataEHMn4_up_R] = ...
		Get_EHDistrib(GL, spin(1), gamma, shiftE);
	[dataEHMn4_dn_L,dataEHMn4_dn_R] = ...
		Get_EHDistrib(GL, spin(2), gamma, shiftE);
	Plot_EHDistrib(dataEHMn4_up_L,dataEHMn4_up_R, dataEHMn4_dn_L,dataEHMn4_dn_R, ...
		N, CH(2), minmax_E, gamma);
	
	if isSavePDF; fig2pdf(gcf,sprintf('p4_N%02i_EH-Distrib_',N)); end;
%}
	%============================================
	% COMBINED PLOTS - EPS
	%============================================
	caseMn = 3;
	figId = FigId(figId,'Combined for Mn3');
	PlotCombined(dataPrMn3_L,dataPrMn3_R, ...
		dataEHMn3_up_L,dataEHMn3_up_R, dataDOSMn3, caseMn);
	if isSavePDF; fig2pdf(gcf,sprintf('p5_N%02i_States-Combined_',N)); end;
	if isSaveEPS; fig2eps(gcf,sprintf('dos-nenh-Mn3-t%0.2f',t0)); end;
	
	caseMn = 4;
	figId = FigId(figId,'Combined for Mn4');
	PlotCombined(dataPrMn4_L,dataPrMn4_R, ...
		dataEHMn4_up_L,dataEHMn4_up_R, dataDOSMn4, caseMn);
	if isSavePDF; fig2pdf(gcf,sprintf('p6_N%02i_States-Combined_',N)); end;
	if isSaveEPS; fig2eps(gcf,sprintf('dos-nenh-Mn4-t%0.2f',t0)); end;
end
%====================================================================
function data = Get_DOS(H_CH0, H_CH1, H_CH2, shiftE)
	E_CH0 = eig(H_CH0(:,:,1));	% both spins have same energy
	E_CH1_up = eig(H_CH1(:,:,1));
	E_CH1_dn = eig(H_CH1(:,:,2));
	E_CH2_up = eig(H_CH2(:,:,1));
	E_CH2_dn = eig(H_CH2(:,:,2));

	data = [E_CH0,E_CH1_up,E_CH1_dn,E_CH2_up,E_CH2_dn];
	data = data + shiftE;
end

function [dataDOS,dataDOSMn3,dataDOSMn4] = Plot_DOS(data, N, gamma, minmax_E)
	global PAR
	
	E0 = data(:,1);
	E1_up = data(:,2);
	E1_dn = data(:,3);
	E2_up = data(:,4);
	E2_dn = data(:,5);
	
	E1_up(PAR.iBndSt3, 1) = 0;
	E2_up(PAR.iBndSt4, 1) = 0;
	

	nE = length(E0);
	xE = linspace(minmax_E(1),minmax_E(2), 800);

	% Cauchy-Lorentz probability density function
	pdfCL = @(x,x0) (gamma./pi) ./ ((x-x0).^2 + gamma.^2);

	yE0 = zeros(size(xE));
	yE1_up = yE0;
	yE1_dn = yE0;
	yE2_up = yE0;
	yE2_dn = yE0;
	for i=1:nE
		yE0 = yE0 + pdfCL(xE,E0(i));
		yE1_up = yE1_up + pdfCL(xE,E1_up(i));
		yE1_dn = yE1_dn + pdfCL(xE,E1_dn(i));
		yE2_up = yE2_up + pdfCL(xE,E2_up(i));
		yE2_dn = yE2_dn + pdfCL(xE,E2_dn(i));
	end
	% normalize
	scale = 1 / N^2;
	yE0 = yE0 * scale;
	yE1_up = yE1_up * scale;
	yE1_dn = yE1_dn * scale;
	yE2_up = yE2_up * scale;
	yE2_dn = yE2_dn * scale;
	
	% export data
	dataDOS = [xE; yE0]';
	dataDOSMn3 = [xE; yE1_up]';
	dataDOSMn4 = [xE; yE2_up]';

	% numerical integral
	intCL = trapz(xE,yE0);

	% plotting
	hold on;

	plot(xE, 4.0+yE2_dn, '-', 'Color',[0,.6,.6], 'LineWidth',2)
	plot(xE, 3.0+yE2_up, '-', 'Color',[0,0,1], 'LineWidth',2)
	plot(xE, 2.0+yE1_dn, '-', 'Color',[.6,.6,0], 'LineWidth',2)
	plot(xE, 1.0+yE1_up, '-', 'Color',[1,0,0], 'LineWidth',2)
	plot(xE, yE0, '-', 'Color',[0,.6,0], 'LineWidth',2)

	hold off;
	% labels
	xlim(minmax_E);
	ylim([0,6]);
	box('on');
	grid on;
	xlabel('Energy (eV)');
	ylabel('DOS per Site: D(\epsilon)');
	title(sprintf('Density of States: N%d, \\gamma = %.2f, \\int D = %.4f',N,gamma,intCL));
	legend( ...
		'CH at Mn^{4+}, \downarrow', 'CH at Mn^{4+}, \uparrow', ...
		'CH at Mn^{3+}, \downarrow', 'CH at Mn^{3+}, \uparrow', ...
		'no CH', ...
		'Location','NorthEast');
end
function Plot_DOS_diff(dataDOS,dataDOSMn3,dataDOSMn4, minmax_E, t0)

	xE = dataDOS(:,1);
	dMn3 = dataDOSMn3(:,2) - dataDOS(:,2);
	dMn4 = dataDOSMn4(:,2) - dataDOS(:,2);
	
	% plotting
	hold on;
	plot(xE, dataDOS(:,2), '-', 'Color',[0.6,1,0.6], 'LineWidth',2)
	
	h2 = plot(xE, 0.1 + dMn4, '-', 'Color',[0,0,1], 'LineWidth',2)
	h1 = plot(xE, dMn3, '-', 'Color',[1,0,0], 'LineWidth',2)

	hold off;
	% labels
	xlim(minmax_E);
	ylim([-0.05, 0.15]);
	box('on');
	grid on;
	xlabel('Energy (eV)');
	ylabel('Difference DOS per Site: \delta D(\epsilon)');
	title(sprintf('Difference Density of States: t_0= %g eV',t0));
	legend( [h2,h1], ...
		'CH at Mn^{4+}, \uparrow', ...
		'CH at Mn^{3+}, \uparrow', ...
		'Location','NorthEast');
end

function [data_L,data_R] = PlotProjections(H_CH0, H_CH1, spin, N, minmax_E, gamma, stCase, shiftE)
	[V0,E0] = eig(H_CH0);	E0 = diag(E0);
	[V1,E1] = eig(H_CH1);	E1 = diag(E1);
		
	E0 = E0 + shiftE;
	E1 = E1 + shiftE;

	nE = length(E0);
	nF = nE / 8;
	
%{
% TEMP: one value calculation for NO-EXCITATION case
Cnm = inv(V0.').' * V1;
d = det(Cnm(1:nF,1:nF));
I0 = d*conj(d);
I0
%}	
	% Create Excitation matrix for excitation projection
	C01 = abs(  inv(V0.').' * V1  ).^2;
	Excit_H = C01(   1:nF, nF+1:nE);
	Excit_E = C01(nF+1:nE,    1:nF);
	% calc. projected data
	D_CH0 = [sum(Excit_H, 2); sum(Excit_E, 2)];
	D_CH1 = [sum(Excit_E, 1), sum(Excit_H, 1)]';
	
	% Cauchy-Lorentz probability density function
	pdfCL = @(x,x0) (gamma./pi) ./ ((x-x0).^2 + gamma.^2);
	
	xE_L = linspace(minmax_E(1),0,200);
	xE_R = linspace(0,minmax_E(2),600);		% refine to 60000, if necessary
	yE0_L = zeros(size(xE_L));
	yE0_R = zeros(size(xE_R));
	yE1_L = yE0_L;
	yE1_R = yE0_R;
	for i=1:nF
		yE0_L = yE0_L + D_CH0(i) * pdfCL(xE_L,E0(i));
		yE1_L = yE1_L + D_CH1(i) * pdfCL(xE_L,E1(i));
	end
	for i=nF+1:nE
		yE0_R = yE0_R + D_CH0(i) * pdfCL(xE_R,E0(i));
		yE1_R = yE1_R + D_CH1(i) * pdfCL(xE_R,E1(i));
	end
	factor = 1 / N^2;
	yE0_L = yE0_L * factor;
	yE1_L = yE1_L * factor;
	yE0_R = yE0_R * factor;
	yE1_R = yE1_R * factor;
	
	%intCL = trapz(xE,yE0)
	%intCL = trapz(xE,yE1)
	
	% plotting data
	subplot(2,1,spin);
	%clf;
	hold on;
	
	plot(xE_L, yE1_L, '-r', 'LineWidth',2);
	plot(xE_L, yE0_L, '-k', 'LineWidth',2);
	
	plot(xE_R, yE1_R, '-r', 'LineWidth',2);
	plot(xE_R, yE0_R, '-k', 'LineWidth',2);
	
	minmax_y = get(gca,'YLim');
	plot([0,0],minmax_y, '--g', 'LineWidth',2);
	
	% export
	data_L = [xE_L; yE0_L; yE1_L]';
	data_R = [xE_R; yE0_R; yE1_R]';
	
	hold off;
	xlim(minmax_E);
	box('on');
	grid on;
	xlabel('Energy (eV)');
	ylabel('Projected States per Site');
	
	switch spin
		case 1
			stSp = '\uparrow';
		case 2
			stSp = '\downarrow';
	end
	title(sprintf('States Projection for CH at %s, spin: %s, N = %d, \\gamma = %.2f', stCase, stSp, N, gamma));
	
	legend('Proj. to CH1','Proj. to CH0');
end

function [data_L,data_R] = Get_EHDistrib(GL, spin, gamma, shiftE)
	rixs = GL.RIXS(GL.RIXS(:,7)==spin, 1:4);
	energ = GL.MAP_CH0(:,1,spin);
	energ = energ + shiftE;
	
	% COLLECT DATA
	nE = size(energ, 1);
	nF = round(nE / 8);	% Fermi threshhold
	data = zeros(nE,2);
	spoff = [1, 0];
	for iE = 1:nE
		E = energ(iE);
		if iE <= nF
			I = sum( rixs(rixs(:,1) == (2*iE-spoff(spin)), 3) );
			data(iE,:) = [I, E];
		else
			I = sum( rixs(rixs(:,2) == (2*iE-spoff(spin)), 3) );
			data(iE,:) = [I, E];
		end
	end
	%minmax_E = [floor(min(data(:,2))), ceil(max(data(:,2)))];
	minmax_E = [-3,9];

	% Lorentzian:
	pdfCL = @(x,x0) (gamma./pi) ./ ((x-x0).^2 + gamma.^2);
	
	xCL_L = linspace(minmax_E(1),0,200);
	xCL_R = linspace(0,minmax_E(2),600);
	yCL_L = 0 * xCL_L;
	yCL_R = 0 * xCL_R;
	for iE = 1:nF
		yCL_L = yCL_L + data(iE,1) .* pdfCL(xCL_L, data(iE,2));
	end
	for iE = nF+1:nE
		yCL_R = yCL_R + data(iE,1) .* pdfCL(xCL_R, data(iE,2));
	end
	data_L = [xCL_L', yCL_L'];
	data_R = [xCL_R', yCL_R'];
end
function Plot_EHDistrib(data_up_L,data_up_R, data_dn_L,data_dn_R, N, CH, minmax_E, gamma)
	if CH == 1
		subplot(2,1,1);
	else
		subplot(2,1,2);
	end
	
	hold on;
	plot(data_up_L(:,1),data_up_L(:,2), '-r', 'LineWidth',2);
	plot(data_dn_L(:,1),data_dn_L(:,2), '-b', 'LineWidth',2);
	
	plot(data_up_R(:,1),data_up_R(:,2), '-r', 'LineWidth',2);
	plot(data_dn_R(:,1),data_dn_R(:,2), '-b', 'LineWidth',2);
	
	minmax_y = get(gca,'YLim');
	plot([0,0],minmax_y, '--g', 'LineWidth',2);
	hold off;
	
	box('on');
	grid('on')
	xlim(minmax_E);
	switch CH
		case 1
			stCH = 'Mn^{3+}';
		case 2
			stCH = 'Mn^{4+}';
	end
	title(sprintf('E-H Distribution from RIXS for CH at %s: N=%i, \\gamma = %.2f',stCH,N,gamma));
	xlabel('Energy (eV)');
	ylabel('Integrated Intensity');
	
	legend('spin: \uparrow','spin: \downarrow');
end

function t0 = GetVal_t0(N)
	load( sprintf('_N%02i_data_/_main_/N%02i_CH0__LastState.mat',N,N) );
	t0 = Eg.C.t0;
end
function PlotCombined(dataPr_L,dataPr_R, dataEH_L,dataEH_R, dataDOS, caseMn)
	global PAR

	minmax_E = PAR.minmax_E;
	if caseMn == 3
		iBndSt = PAR.iBndSt3;
		BndSt = PAR.data(iBndSt,2);
	else
		iBndSt = PAR.iBndSt4;
		BndSt = PAR.data(iBndSt,4);
	end
	%------------------------

	lw = 2.5;
	FontSize = 20;
	aspect = [1 0.4 1];
	
	colEH  = [0.8,0.5,0];
	colFin = [0,0,0.6];
	colInt = [1,0,0];
	colDOS = [0.6,0.6,0];
	
	dataPr = [dataPr_L; dataPr_R];
	
	int_Pr = trapz(dataPr_L(:,1),dataPr_L(:,2)) + trapz(dataPr_R(:,1),dataPr_R(:,2));
	int_EH = trapz(dataEH_L(:,1),dataEH_L(:,2)) + trapz(dataEH_R(:,1),dataEH_R(:,2));

	% set all min/max values
	maxPr = max( [max(dataPr_L(:,2)), max(dataPr_L(:,3))] );
	[nice_maxPr,scalePr,exponentPr] = NiceMax(maxPr);
	minmax_y = [0, nice_maxPr*scalePr];
	minmax_EH = [0, nice_maxPr*(int_EH/int_Pr)];
	[nice_maxDOS,~,~] = NiceMax(max(dataDOS(:,2)));
	minmax_DOS = [0, nice_maxDOS];
	
	% re-scale where necessary
%	dataEH_L(:,2) = dataEH_L(:,2) * (int_Pr / int_EH);
%	dataEH_R(:,2) = dataEH_R(:,2) * (int_Pr / int_EH);
	
	%------------------------------------------------------
	% UPPER HALF:
	subplot(2,1,1); hold on;
	
	% plot upper half
	hp1 = line(dataEH_L(:,1),dataEH_L(:,2), 'LineStyle','-', 'Color',colEH, 'LineWidth',lw);
	      line(dataEH_R(:,1),dataEH_R(:,2), 'LineStyle','-', 'Color',colEH, 'LineWidth',lw);
		  
	% axis
	ax1 = gca;	
	set(ax1, ...
		'XAxisLocation','top', 'YAxisLocation','right', ...
		'XColor','k','YColor',colEH);

	ax2 = axes('Position',get(ax1,'Position'), ...
		'XAxisLocation','bottom', 'YAxisLocation','left', ...
		'Color','none', 'XColor','k','YColor',colFin);	

	% plot thin vert. line for Fermi level
	line([0,0],minmax_y, 'LineStyle','--', 'Color',0.5*[1,1,1], 'LineWidth',1.5);
	
%	hp2 = line(dataPr_L(:,1),dataPr_L(:,2)*scalePr, 'LineStyle','-', 'Color',colFin, 'LineWidth',lw);
%	      line(dataPr_R(:,1),dataPr_R(:,2)*scalePr, 'LineStyle','-', 'Color',colFin, 'LineWidth',lw);
	hp2 = line(dataPr(:,1),dataPr(:,2)*scalePr, 'LineStyle','-', 'Color',colFin, 'LineWidth',lw);
	
	hold off;
	
FigText(minmax_E(1)+0.1,minmax_y(2), '(a)', FontSize,0,'left','top');
	
	set(ax1, 'XLim',minmax_E, 'YLim',minmax_EH);
	set(ax2, 'XLim',minmax_E, 'YLim',minmax_y);
	
	set(ax1, 'LineWidth',2, 'FontSize',FontSize);
	set(ax2, 'LineWidth',2, 'FontSize',FontSize);
	
	set(ax1, 'XTick',-4:2:12, 'XTickLabel','');
	set(ax2, 'XTick',-4:2:12, 'XTickLabel','');
	
	ylabel(ax1,'Electron and Hole RIXS', 'FontSize',FontSize, 'Color','k');
	ylabel(ax2,sprintf('Final Distrib. (x10^{%d})',exponentPr), 'FontSize',FontSize, 'Color','k');
%	title(stTitle, 'FontSize',FontSize);
	

	hl1 = legend([hp1,hp2],'I_{RIXS,\uparrow}^{h}, I_{RIXS,\uparrow}^{e}', ...
		'n_{fin,\uparrow}^{h}, n_{fin,\uparrow}^{e}');
	set(hl1,'Color','none');
	box(hl1,'off');
	set(hl1,'EdgeColor',[1 1 1]);
%	set(hl1,'FontName','Times New Roman');
	
%	set(ax1,'PlotBoxAspectRatio',aspect);
%	set(ax2,'PlotBoxAspectRatio',aspect);
	
	pos = [0.13, 0.53, 0.7, 0.2];
	set(ax1, 'Position',pos)
	set(ax2, 'Position',pos)

	%------------------------------------------------------
	% LOWER HALF:
	subplot(2,1,2); hold on;
	
	% plot lower half
	hp3 = line(dataDOS(:,1),dataDOS(:,2), 'LineStyle','-', 'Color',colDOS, 'LineWidth',lw);
	% display bound states, as vertical lines
	for ibs = 1:length(BndSt)
		line(BndSt(ibs)*[1,1], 0.5*minmax_DOS, 'LineStyle','-', 'Color',colDOS, 'LineWidth',1.5*lw);
		plot(BndSt(ibs), 0.5*minmax_DOS(2), 'o', 'Color',colDOS, ...
			'LineWidth',2*lw, 'MarkerFaceColor',colDOS)
	end
	
	% axis
	ax3 = gca;	
	set(ax3, ...
		'XAxisLocation','top', 'YAxisLocation','right', ...
		'XColor','k','YColor',colDOS);

	ax4 = axes('Position',get(ax3,'Position'), ...
		'XAxisLocation','bottom', 'YAxisLocation','left', ...
		'Color','none', 'XColor','k','YColor',colInt);	

	% plot thin vert. line for Fermi level
	line([0,0],minmax_y, 'LineStyle','--', 'Color',0.5*[1,1,1], 'LineWidth',1.5);
	
%	hp4 = line(dataPr_L(:,1),dataPr_L(:,3)*scalePr, 'LineStyle','-', 'Color',colInt, 'LineWidth',lw);
%	      line(dataPr_R(:,1),dataPr_R(:,3)*scalePr, 'LineStyle','-', 'Color',colInt, 'LineWidth',lw);
	hp4 = line(dataPr(:,1),dataPr(:,3)*scalePr, 'LineStyle','-', 'Color',colInt, 'LineWidth',lw);
	
	hold off;
	
FigText(minmax_E(1)+0.1,minmax_y(2), '(b)', FontSize,0,'left','top');

	set(ax3, 'XLim',minmax_E, 'YLim',minmax_DOS);
	set(ax4, 'XLim',minmax_E, 'YLim',minmax_y);
	
	set(ax3, 'LineWidth',2, 'FontSize',FontSize);
	set(ax4, 'LineWidth',2, 'FontSize',FontSize);
	
	set(ax3, 'XTick',-4:2:12, 'XTickLabel','');
	set(ax4, 'XTick',-4:2:12);

	xlabel('Energy (eV)', 'FontSize',FontSize);
	ylabel(ax3,'DOS per Site (eV^{-1})', 'FontSize',FontSize, 'Color','k');
	ylabel(ax4,sprintf('Intermediate Distrib. (x10^{%d})',exponentPr), 'FontSize',FontSize, 'Color','k');
	
	hl2 = legend([hp3,hp4],'DOS_{\uparrow}', 'n_{int,\uparrow}^{e}, n_{int,\uparrow}^{h}');
	set(hl2,'Color','none');
	box(hl2, 'off');
	set(hl2,'EdgeColor',[1 1 1]);
%	set(hl2,'FontName','Times New Roman');
	
%	set(ax3,'PlotBoxAspectRatio',aspect);
%	set(ax4,'PlotBoxAspectRatio',aspect);
	
	pos = [0.13, 0.15, 0.7, 0.2];
	set(ax3, 'Position',pos)
	set(ax4, 'Position',pos)
	
	% integration check:
	%{
	disp('INTEGRAL VALUES:')
	int_EH_L = trapz(dataEH_L(:,1),dataEH_L(:,2))
	int_EH_R = trapz(dataEH_R(:,1),dataEH_R(:,2))
	int_Pr0_L = trapz(dataPr_L(:,1),dataPr_L(:,2))
	int_Pr1_L = trapz(dataPr_L(:,1),dataPr_L(:,3))
	int_Pr0_R = trapz(dataPr_L(:,1),dataPr_L(:,2))
	int_Pr1_R = trapz(dataPr_L(:,1),dataPr_L(:,3))
	int_DOS = trapz(dataDOS(:,1),dataDOS(:,2))
	%}
end
%====================================================================



function SpecialData(str, W, dataPrMn_R)

	[I0,i0] = max(dataPrMn_R(:,2));	% max for proj to CH0
	[I1,i1] = max(dataPrMn_R(:,3));	% max for proj to CH1
	E0 = dataPrMn_R(i0,1);
	E1 = dataPrMn_R(i1,1);
	
	fprintf('--------------------------\n');
	fprintf('%s\n',str);
	fprintf('   W = %.4f eV\n',W);
	fprintf('  E0 = %.4f eV, I0 = %.4f (black)\n',E0,I0);
	fprintf('  E1 = %.4f eV, I1 = %.4f (red)\n',E1,I1);
	fprintf('W/E0 = %.4f\n',W/E0);
	fprintf('W/E1 = %.4f <---\n',W/E1);
	fprintf('--------------------------\n');
end




function Plot_Energies(data,t0)
	nd = size(data,1);
	ind = 1:nd;
    minmax_x = [-10,nd+10];
    minmax_E = [-4,12];

    clrE0 = [0,0,0];
    clrE1 = [1,0,0];
    clrE2 = [0,0,1];
    ms = 3;
	arr = data(data(:,1) <= 0.0, 1);
	na = size(arr,1);
	
	subplot(2,1,1);
	% draw vertical line at Fermi
	plot(ind(na)*[1,1], minmax_E, '--g');
	hold on;
	h0 = plot(ind,data(:,1), 'o','MarkerSize',ms, 'Color',clrE0);
    h1 = plot(ind,data(:,2), 'o','MarkerSize',ms, 'Color',clrE1, ...
		'MarkerFace',clrE1);
	hold off;    
    % axis matters
	box('on');
	title(sprintf('Energies: t_0= %g, Mn^{3+}',t0));
	xlabel('Index');
	ylabel('Energy (eV)');
    cLeg = {'E_0';'E^{Mn3+}'};
    legend([h0,h1],cLeg, 'Location','SouthEast');
	xlim(minmax_x);
	ylim(minmax_E);
	
	
	subplot(2,1,2);
	% draw vertical line at Fermi
	plot(ind(na)*[1,1], minmax_E, '--g');
	hold on;
	h0 = plot(ind,data(:,1), 'o','MarkerSize',ms, 'Color',clrE0);
    h1 = plot(ind,data(:,4), 'o','MarkerSize',ms, 'Color',clrE2, ...
		'MarkerFace',clrE2);
	hold off;
	% axis matters
	box('on');
	title(sprintf('Energies: t_0= %g, Mn^{4+}',t0));
	xlabel('Index');
	ylabel('Energy (eV)');
    cLeg = {'E_0';'E^{Mn4+}'};
    legend([h0,h1],cLeg, 'Location','SouthEast');
	xlim(minmax_x);
	ylim(minmax_E);
end







